@@ -47,8 +47,8 @@
 KPGDataTable::KPGDataTable(KPGDataTableChildView *parent, 
 	KPoGreView *pPoGreView,
 	KXMLGUIFactory *pXmlGuiFactory,
-	KPGConnection *pConnection, 
-	const QString & strNamespaceName,
+	const PGSTD::string& strConnectionOptions,
+ 	const QString & strNamespaceName,
 	const QString & strTableName,
 	const ListTableColumns & listTableColumns,
 	const MapIndexKey & mapIndexKey,
@@ -63,11 +63,11 @@ KPGDataTable::KPGDataTable(KPGDataTableChildView *parent,
  	m_pKateXmlEditorDialog(pKateXmlEditorDialog)
 {
 	m_bOpeningReload = true;
-	m_state = stateRefresh;
+	m_state = refresh;
 	m_editedRow = -1;
 	m_bInplaceEditing = false;
 	
-	m_pConnection = pConnection;
+	m_strConnectionOptions = strConnectionOptions;
 	m_strNamespaceName = strNamespaceName;
 	m_strTableName = strTableName;
 	m_strWherePredicate = strWherePredicate;
@@ -97,11 +97,11 @@ KPGDataTable::KPGDataTable(KPGDataTableChildView *parent,
 	
 	m_pActEditCell = new KAction(i18n("Edit cell"), "edittool", Key_F2, this, SLOT(slotEditCell()), actionCollection(), "datatable_edit_cell");
 	
-	m_pActClearCell = new KAction(i18n("Clear cell"), "deletecell", Key_Delete, this, SLOT(slotClearCell()), actionCollection(), "datatable_clear_cell");
+	m_pActClearCell = new KAction(i18n("Clear cell"), "editclear", Key_Delete, this, SLOT(slotClearCell()), actionCollection(), "datatable_clear_cell");
 	
-	m_pActInsertRow = new KAction(i18n("Insert row"), "insert_table_row", CTRL+Key_Insert, this, SLOT(slotInsertRow()), actionCollection(), "datatable_insert_row");
+	m_pActInsertRow = new KAction(i18n("Insert row"), "insrow", CTRL+Key_Insert, this, SLOT(slotInsertRow()), actionCollection(), "datatable_insert_row");
 	
-	m_pActDeleteRow = new KAction(i18n("Delete row"), "delete_table_row", CTRL+Key_Delete, this, SLOT(slotDeleteRow()), actionCollection(), "datatable_delete_row");
+	m_pActDeleteRow = new KAction(i18n("Delete row"), "remrow", CTRL+Key_Delete, this, SLOT(slotDeleteRow()), actionCollection(), "datatable_delete_row");
 	
 	m_pActCommitChanges = new KAction(i18n("Update changes"), "ok", CTRL+Key_Return, this, SLOT(slotCommitChanges()), actionCollection(), "datatable_commit_changes");
 	
@@ -156,8 +156,20 @@ KPGDataTable::KPGDataTable(KPGDataTableChildView *parent,
 	setSorting( false );
   	setSelectionMode( QTable::SingleRow );
   	
-  	m_ConnectionInThread.setEventReceiver(this, &m_pqxxResult);
+	m_connectionInThread.setEventReceiver(this, &m_pqxxResult);
 		
+	// Open connection
+	try
+	{
+		m_connectionInThread.connectToServer(m_strConnectionOptions);
+	}
+	catch (const std::exception &e)
+	{
+		kdError() << "Failed to open connection " << e.what() << endl;
+		KMessageBox::sorry(this, e.what());
+		return;
+	}
+	
 	disableAllActions();
 	
 	connect(this, SIGNAL(currentChanged(int, int)), this, SLOT(slotCurrentChanged(int, int)));
@@ -174,6 +186,9 @@ KPGDataTable::KPGDataTable(KPGDataTableChildView *parent,
 
 KPGDataTable::~KPGDataTable()
 {
+	// Close connection
+	m_connectionInThread.disconnectFromServer(); // close connection if any
+	
 	if(m_pFind != 0) delete m_pFind;
 
 	removeFromGuiFactory();
@@ -336,7 +351,7 @@ bool KPGDataTable::eventFilter(QObject *pObject, QEvent *pEvent)
 					}
 				}
 				
-				if((m_state == stateUpdate) || (m_state == stateInsert))
+				if((m_state == update) || (m_state == insert))
 				{
 					//kdDebug() << "Keyboard event filter fired" << endl;
 					if(commitChanges() == false) return true; // not allow change current cell, if commitChanges() fails
@@ -363,7 +378,7 @@ void KPGDataTable::contentsMousePressEvent(QMouseEvent* pMouseEvent)
 		fixRow2( nRow, pMouseEvent->pos().y() );
 						
 		// If we in Edit or Insert mode, send dirty row to database
-		if((m_editedRow >= 0) && ((m_state == stateUpdate) || (m_state == stateInsert)) && (m_editedRow != nRow))
+		if((m_editedRow >= 0) && ((m_state == update) || (m_state == insert)) && (m_editedRow != nRow))
 		{
 			//kdDebug() << "Mouse event filter fired" << endl;
 				
@@ -434,7 +449,7 @@ void KPGDataTable::disableAllActions()
 // Enable/disable Datatable related KActions with regards to datatable state
 void KPGDataTable::setActions()
 {
-	if(m_state == stateRefresh)
+	if(m_state == refresh)
 	{
 		disableAllActions();
 		m_pActStopReload->setEnabled(true);
@@ -454,18 +469,18 @@ void KPGDataTable::setActions()
 		
 		m_pActEditCell->setEnabled(!m_bInplaceEditing);
 		m_pActClearCell->setEnabled(!m_bInplaceEditing);
-		m_pActDeleteRow->setEnabled(((m_state == stateView) && !m_bInplaceEditing));
+		m_pActDeleteRow->setEnabled(((m_state == view) && !m_bInplaceEditing));
 		
-		m_pActCommitChanges->setEnabled((m_state != stateView) && !m_bInplaceEditing);
-		m_pActCancelChanges->setEnabled((m_state != stateView));
+		m_pActCommitChanges->setEnabled((m_state != view) && !m_bInplaceEditing);
+		m_pActCancelChanges->setEnabled((m_state != view));
     }
     else
     {
     	disableAllActions();
     }
     
-    m_pActInsertRow->setEnabled((m_state == stateView) && !m_bInplaceEditing);
-    m_pActReloadData->setEnabled((m_state == stateView) && !m_bInplaceEditing);
+    m_pActInsertRow->setEnabled((m_state == view) && !m_bInplaceEditing);
+    m_pActReloadData->setEnabled((m_state == view) && !m_bInplaceEditing);
     
     m_pActEditFind->setEnabled(numRows() > 0);
 }
@@ -494,30 +509,16 @@ void KPGDataTable::reloadData()
 	setNumRows(0);
 	setNumCols(0);
 		
-	m_state = stateRefresh;
+	m_state = refresh;
 	m_editedRow = -1;
 	disableAllActions();
 	m_pActStopReload->setEnabled(true);
 	setEnabled(false);
 	((QWidget *) parent())->setCursor(KCursor::waitCursor());
-		
-	// Run connection in thread
-	m_ConnectionInThread.disconnectFromServer(); // close connection if any
-	
-	try
-	{
-		m_ConnectionInThread.connectToServer(m_pConnection->options());
-	}
-	catch (const std::exception &e)
-    {
-        kdError() << "Failed to open connection " << e.what() << endl;
-        KMessageBox::sorry(this, e.what());
-        return;
-    }
-    
+	    
 	QString strSql(sqlForSelectAllRows());
-	m_ConnectionInThread.setSQL(strSql, KPGConnection::eTransNormal);
-	m_ConnectionInThread.start();
+	m_connectionInThread.setSQL(strSql, KPGConnection::eTransNormal);
+	m_connectionInThread.start();
 }
 
 void KPGDataTable::customEvent(QCustomEvent *pEvent)
@@ -534,9 +535,9 @@ void KPGDataTable::customEvent(QCustomEvent *pEvent)
 			
 	((QWidget *) parent())->setCursor(KCursor::arrowCursor());
 	setEnabled(true);
-	m_ConnectionInThread.wait();
+	m_connectionInThread.wait();
 	
-	m_state = stateView;
+	m_state = view;
 	setActions();
 }
 
@@ -649,7 +650,7 @@ void KPGDataTable::displayOneRow(int nTableDataRow, unsigned int nRow, unsigned
 {
 	for(unsigned int nCol = 0; nCol < nTotalCols; nCol++)
 	{
-		QString strValue(m_pConnection->textCodec()->toUnicode(pqxxResult[nRow][nCol].c_str()));
+		QString strValue(m_connectionInThread.connection()->textCodec()->toUnicode(pqxxResult[nRow][nCol].c_str()));
 		
 		// Truncate long BLOBs
 	   if((m_listTableColumns[nCol].typName() == "text") ||
@@ -669,16 +670,28 @@ void KPGDataTable::displayOneRow(int nTableDataRow, unsigned int nRow, unsigned
 
 void KPGDataTable::stopReload()
 {
-	if(m_ConnectionInThread.running ())
+	if(m_connectionInThread.running ())
 	{
-		m_ConnectionInThread.terminate();
-		m_ConnectionInThread.wait();
-		m_ConnectionInThread.leaveConnection();
+		m_connectionInThread.terminate();
+		m_connectionInThread.wait();
+		m_connectionInThread.leaveConnection();
 				
 		m_pqxxResult.clear(); // free memory
+				
+		m_state = view;
+		
+		try
+		{
+			m_connectionInThread.connectToServer(m_strConnectionOptions);
+			setActions();
+		}
+		catch (const std::exception &e)
+		{
+			kdError() << "Failed to open connection " << e.what() << endl;
+			KMessageBox::sorry(this, e.what());
+			return;
+		}
 		
-		m_state = stateView;
-		setActions();
 		((QWidget *) parent())->setCursor(KCursor::arrowCursor());
 	} 
 }
@@ -726,7 +739,7 @@ void KPGDataTable::prepareInsertStatement(const std::string &stdstrPrepStmtName)
 	strDml.append(")");
 	kdDebug() << strDml << endl;
 	
-	pqxx::prepare::declaration pqxxPrepDecl = m_pConnection->prepare(stdstrPrepStmtName, strDml);
+	pqxx::prepare::declaration pqxxPrepDecl = m_connectionInThread.connection()->prepare(stdstrPrepStmtName, strDml);
 	
 	// Add declaring parameters to prepared statements - INSERTed fields
 	for(int currentCol = 0; currentCol < numCols(); currentCol++)
@@ -737,13 +750,13 @@ void KPGDataTable::prepareInsertStatement(const std::string &stdstrPrepStmtName)
        	    {
        	        if(m_bAutoGeneratedPrimaryKey && (m_strPKColumnName == m_listTableColumns[currentCol].name()))
        	        {
-       	        	m_pConnection->setPrepareDeclaration(pqxxPrepDecl, m_listTableColumns[currentCol].typName());
+       	        	m_connectionInThread.connection()->setPrepareDeclaration(pqxxPrepDecl, m_listTableColumns[currentCol].typName());
        	        }
       		}
       	 }
        	 else
        	 {
-       	    	m_pConnection->setPrepareDeclaration(pqxxPrepDecl, m_listTableColumns[currentCol].typName());
+       	    	m_connectionInThread.connection()->setPrepareDeclaration(pqxxPrepDecl, m_listTableColumns[currentCol].typName());
        	 }
     }
 }
@@ -793,7 +806,7 @@ void KPGDataTable::prepareUpdateStatement(const std::string &stdstrPrepStmtName)
 	strDml.append(wherePredicateForPrimaryKey(iParamsIndex));
 	kdDebug() << strDml << endl;
 	
-	pqxx::prepare::declaration pqxxPrepDecl = m_pConnection->prepare(stdstrPrepStmtName, strDml);
+	pqxx::prepare::declaration pqxxPrepDecl = m_connectionInThread.connection()->prepare(stdstrPrepStmtName, strDml);
 	
 	// Add declaring parameters to prepared statements - UPDATEd fields
 	currentCol = 0;
@@ -803,7 +816,7 @@ void KPGDataTable::prepareUpdateStatement(const std::string &stdstrPrepStmtName)
        	{
        		if((text(m_editedRow, currentCol) != QString::null) && (text(m_editedRow, currentCol).isEmpty() == false))
        		{   
-       		   m_pConnection->setPrepareDeclaration(pqxxPrepDecl, m_listTableColumns[currentCol].typName());
+       		   m_connectionInThread.connection()->setPrepareDeclaration(pqxxPrepDecl, m_listTableColumns[currentCol].typName());
        	    }
        	}
        	currentCol++;
@@ -823,7 +836,7 @@ void KPGDataTable::prepareDeleteStatement(const std::string &stdstrPrepStmtName)
 	strDml.append(wherePredicateForPrimaryKey(0));
 	kdDebug() << strDml << endl;
 	
-	pqxx::prepare::declaration pqxxPrepDecl = m_pConnection->prepare(stdstrPrepStmtName, strDml);
+	pqxx::prepare::declaration pqxxPrepDecl = m_connectionInThread.connection()->prepare(stdstrPrepStmtName, strDml);
 	
     // Add declaring parameters to prepared statements - primary key fields
 	for(MapIndexKey::ConstIterator it = m_mapIndexKey.begin(); it != m_mapIndexKey.end(); it++) 
@@ -838,7 +851,7 @@ void KPGDataTable::prepareSelectStatement(const std::string &stdstrPrepStmtName)
 	QString strSql(sqlForSelectOneRow());
 	kdDebug() << strSql << endl;
 	
-	pqxx::prepare::declaration pqxxPrepDecl = m_pConnection->prepare(stdstrPrepStmtName, strSql);
+	pqxx::prepare::declaration pqxxPrepDecl = m_connectionInThread.connection()->prepare(stdstrPrepStmtName, strSql);
 	
     // Add declaring parameters to prepared statements - primary key fields
 	for(MapIndexKey::ConstIterator it = m_mapIndexKey.begin(); it != m_mapIndexKey.end(); it++) 
@@ -851,7 +864,7 @@ void KPGDataTable::prepareSelectStatement(const std::string &stdstrPrepStmtName)
 void KPGDataTable::firstRow()
 {
     // If current row is changed, commit changed row to DB
-    if((m_state == stateUpdate) || (m_state == stateInsert))
+    if((m_state == update) || (m_state == insert))
     {
     	if(commitChanges() == false) return;
     }
@@ -867,7 +880,7 @@ void KPGDataTable::firstRow()
 void KPGDataTable::previousRow()
 {
     // If current row is changed, commit changed row to DB
-    if((m_state == stateUpdate) || (m_state == stateInsert))
+    if((m_state == update) || (m_state == insert))
     {
     	if(commitChanges() == false) return;
     }
@@ -884,7 +897,7 @@ void KPGDataTable::previousRow()
 void KPGDataTable::nextRow()
 {
     // If current row is changed, commit changed row to DB
-    if((m_state == stateUpdate) || (m_state == stateInsert))
+    if((m_state == update) || (m_state == insert))
     {
     	if(commitChanges() == false) return;
     }
@@ -900,7 +913,7 @@ void KPGDataTable::nextRow()
 void KPGDataTable::lastRow()
 {
     // If current row is changed, commit changed row to DB
-    if((m_state == stateUpdate) || (m_state == stateInsert))
+    if((m_state == update) || (m_state == insert))
     {
     	if(commitChanges() == false) return;
     }
@@ -947,9 +960,9 @@ void KPGDataTable::clearCell()
 // Insert new row into data table
 void KPGDataTable::insertRow()
 {
-	if(m_state != stateView)
+	if(m_state != view)
 	{
-		kdError()  << k_funcinfo << "Wrong state, expect stateView" <<  endl;
+		kdError()  << k_funcinfo << "Wrong state, expect view" <<  endl;
 		return;
 	}
 	
@@ -959,7 +972,7 @@ void KPGDataTable::insertRow()
 	insertRows(nRows);
 	
 	setCurrentCell(nRows, 0);
-	m_state = stateInsert;
+	m_state = insert;
 	m_editedRow = nRows;
 	
 	setActions();
@@ -968,9 +981,9 @@ void KPGDataTable::insertRow()
 // Delete selected row from data table
 void KPGDataTable::deleteRow()
 {
-	if(m_state != stateView)
+	if(m_state != view)
 	{
-		kdError() << k_funcinfo "Wrong state, expect stateView" <<  endl;
+		kdError() << k_funcinfo "Wrong state, expect view" <<  endl;
 		return;
 	}
 	
@@ -999,11 +1012,11 @@ bool KPGDataTable::commitChanges()
 	bool bSuccess = true;
 	
 	// If current row is changed, commit changed row to DB
-    if(m_state == stateView)
+    if(m_state == view)
     {
-    	kdError() << k_funcinfo "Wrong state: stateView" <<  endl;
+    	kdError() << k_funcinfo "Wrong state: view" <<  endl;
     }
-    else if(m_state == stateUpdate)
+    else if(m_state == update)
     {
     	//--- UPDATE m_editedRow to database table 
     	
@@ -1072,7 +1085,7 @@ bool KPGDataTable::commitChanges()
 		}
 	}
 	
-	m_state = stateView;
+	m_state = view;
 	m_editedRow = -1;
 	
 	setActions();
@@ -1175,7 +1188,7 @@ void KPGDataTable::refreshRow()
 		prepareSelectStatement(stdstrPrepStmtName);
 		bNeedUnprepare = true;
 				
-		work pqxxXaction(*m_pConnection, stdstrPrepStmtName);
+		work pqxxXaction(*m_connectionInThread.connection(), stdstrPrepStmtName);
 		prepare::invocation pqxxInvocation = pqxxXaction.prepared(stdstrPrepStmtName);
 				
 		// Append primary key values to vParams
@@ -1203,7 +1216,7 @@ void KPGDataTable::refreshRow()
 		displayOneRow(nRow, 0, nTotalCols, pqxxResult);
 		
 		bNeedUnprepare = false;
-		m_pConnection->unprepare(stdstrPrepStmtName);
+		m_connectionInThread.connection()->unprepare(stdstrPrepStmtName);
 		 
 		// Refresh also undo buffer
 		m_listRowFields.clear();
@@ -1218,7 +1231,7 @@ void KPGDataTable::refreshRow()
     {
     	if(bNeedUnprepare)
 		{
-		     m_pConnection->unprepare(stdstrPrepStmtName); 
+		     m_connectionInThread.connection()->unprepare(stdstrPrepStmtName); 
 		}
 		
     	((QWidget *) parent())->setCursor(KCursor::arrowCursor());
@@ -1231,12 +1244,12 @@ void KPGDataTable::refreshRow()
 // Cancel changes in data table
 void KPGDataTable::cancelChanges()
 {
-	if(m_state == stateInsert)
+	if(m_state == insert)
 	{
 		// Remove last row
 		removeRow(numRows() - 1);
 	}
-	else if(m_state == stateUpdate)
+	else if(m_state == update)
 	{
 		// Get back old values 
 		ListRowFields::iterator it;
@@ -1253,7 +1266,7 @@ void KPGDataTable::cancelChanges()
 	}
 	else
 	{
-		kdError() << k_funcinfo "Wrong state: stateView" <<  endl;
+		kdError() << k_funcinfo "Wrong state: view" <<  endl;
 	}
 	
 	// Clear dirty flags
@@ -1263,7 +1276,7 @@ void KPGDataTable::cancelChanges()
 	}
 			
 	m_editedRow = -1;
-	m_state = stateView;
+	m_state = view;
 	
 	setActions();
 }
@@ -1291,7 +1304,7 @@ void KPGDataTable::loadLob(const KURL& url)
 	{
 		((QWidget *) parent())->setCursor(KCursor::waitCursor());
 		
-		work pqxxXaction(*m_pConnection, stdstrPrepStmtName);
+		work pqxxXaction(*m_connectionInThread.connection(), stdstrPrepStmtName);
 		
 		pqxx::largeobject pqxxLargeObject(pqxxXaction);
 		pqxxLargeObject = largeobject(pqxxXaction, url.path());
@@ -1337,7 +1350,7 @@ void KPGDataTable::saveLob(const KURL& url)
 	{
 		((QWidget *) parent())->setCursor(KCursor::waitCursor());
 		
-		work pqxxXaction(*m_pConnection, stdstrPrepStmtName);
+		work pqxxXaction(*m_connectionInThread.connection(), stdstrPrepStmtName);
 		pqxx::largeobject pqxxLargeObject = getLargeObject(nRow, nCol, stdstrPrepStmtName, pqxxXaction);
 		
 		// TODO: Warn when LOB IS NULL
@@ -1377,7 +1390,7 @@ void KPGDataTable::editLobInEditor()
 	
 	try
 	{
-		work pqxxXaction(*m_pConnection, stdstrPrepStmtName);
+		work pqxxXaction(*m_connectionInThread.connection(), stdstrPrepStmtName);
 		
 		pqxx::largeobject pqxxLargeObjectIn = getLargeObject(nRow, nCol, stdstrPrepStmtName, pqxxXaction);
 		largeobjectaccess pqxxLargeObjectAccessIn(pqxxXaction, pqxxLargeObjectIn, PGSTD::ios::in);
@@ -1397,7 +1410,7 @@ void KPGDataTable::editLobInEditor()
             return;
 		}
 		
-		QString strText(m_pConnection->textCodec()->toUnicode(buffer));
+		QString strText(m_connectionInThread.connection()->textCodec()->toUnicode(buffer));
 		
 		if(m_listTableColumns[nCol].typName() == "text")
 		{
@@ -1433,7 +1446,7 @@ void KPGDataTable::editLobInEditor()
        	pqxx::largeobject pqxxLargeObjectOut(pqxxXaction);
 		largeobjectaccess pqxxLargeObjectAccessOut(pqxxXaction, pqxxLargeObjectOut, PGSTD::ios::out);
 			
-		pqxxLargeObjectAccessOut.write((std::string) m_pConnection->textCodec()->fromUnicode(strText));
+		pqxxLargeObjectAccessOut.write((std::string) m_connectionInThread.connection()->textCodec()->fromUnicode(strText));
 		
 		if(setLargeObject(pqxxLargeObjectOut, nRow, nCol, stdstrPrepStmtName, pqxxXaction) == false)
 		{
@@ -1455,14 +1468,14 @@ void KPGDataTable::editLobInEditor()
 // Called, when the current cell in m_pTableData has changed to row, col
 void KPGDataTable::slotCurrentChanged (int nRow, int)
 {
-	if(m_pConnection == 0)
+	if(m_connectionInThread.connection() == 0)
     {
         disableAllActions();
         return;
     }
         
     // Copy row to m_listRowFields to have field values before user edit it
-    if((m_state == stateInsert) || (m_state == stateUpdate))
+    if((m_state == insert) || (m_state == update))
     {
     	if(m_editedRow != nRow)
 		{
@@ -1472,7 +1485,7 @@ void KPGDataTable::slotCurrentChanged (int nRow, int)
 		}
     }
     
-    if(m_state == stateView)
+    if(m_state == view)
     {
     	m_listRowFields.clear();
     	for(int nCol = 0; nCol < numCols(); nCol++)
@@ -1487,18 +1500,18 @@ void KPGDataTable::slotCurrentChanged (int nRow, int)
 // Called, when user changed the value in the m_pTableData
 void KPGDataTable::slotValueChanged(int row, int col)
 {
-	if(m_state == stateRefresh)
+	if(m_state == refresh)
 	{
 		return;
 	}
-	else if(m_state == stateInsert)
+	else if(m_state == insert)
 	{
 		if(m_editedRow != row)
 		{
 			kdError() << k_funcinfo "Rows not match !" <<  endl;
 		}
 	}
-	else if(m_state == stateUpdate)
+	else if(m_state == update)
 	{
 		if(m_editedRow != row)
 		{
@@ -1507,9 +1520,9 @@ void KPGDataTable::slotValueChanged(int row, int col)
 		
 		m_listRowFields[col].setDirty();
 	}
-	else // stateView
+	else // view
 	{
-		m_state = stateUpdate;
+		m_state = update;
 		m_editedRow = row;
 		m_listRowFields[col].setDirty();
 	}
@@ -1520,7 +1533,7 @@ void KPGDataTable::slotValueChanged(int row, int col)
 // Called when mouse button button is double-clicked over m_pTableData
 void KPGDataTable::slotDoubleClicked(int row, int col, int, const QPoint &)
 {
-	if(m_state == stateRefresh)
+	if(m_state == refresh)
 	{
 		return;
 	}
@@ -1530,7 +1543,7 @@ void KPGDataTable::slotDoubleClicked(int row, int col, int, const QPoint &)
 		
 	if(m_listTableColumns[col].typName() == "text")
 	{
-		if(m_state != stateView)
+		if(m_state != view)
 		{
 			KMessageBox::sorry(this, i18n("Can't edit text field during editing or inserting row !"));
 			return;
@@ -1540,7 +1553,7 @@ void KPGDataTable::slotDoubleClicked(int row, int col, int, const QPoint &)
 	}
 	else if(m_listTableColumns[col].typName() == "xml")
 	{
-		if(m_state != stateView)
+		if(m_state != view)
 		{
 			KMessageBox::sorry(this, i18n("Can't edit xml field during editing or inserting row !"));
 			return;
@@ -1550,7 +1563,7 @@ void KPGDataTable::slotDoubleClicked(int row, int col, int, const QPoint &)
 	}	   
    	else if(m_listTableColumns[col].typName() == "bytea")
    	{
-       if(m_state != stateView)
+       if(m_state != view)
 		{
 			KMessageBox::sorry(this, i18n("Can't edit binary field during editing or inserting row !"));
 			return;
@@ -1670,14 +1683,14 @@ void KPGDataTable::fillParametersForPrimaryKey(int nRow, prepare::invocation &pq
     		return;
     	}
         		
-        pqxxInvocation((std::string) m_pConnection->textCodec()->fromUnicode(text(nRow, nCol)));
+        pqxxInvocation((std::string) m_connectionInThread.connection()->textCodec()->fromUnicode(text(nRow, nCol)));
     }
 }
 
 // Run DML on DB server. Return true, if command succesfully performed
 bool KPGDataTable::runDml(EDmlType dmlType)
 {
-	if(m_pConnection == 0)
+	if(m_connectionInThread.connection() == 0)
 	{
 		KMessageBox::error(this, i18n("Not connected"));
 	 	return false;
@@ -1719,7 +1732,7 @@ bool KPGDataTable::runDml(EDmlType dmlType)
 			}
 		}
         
-        work pqxxXaction(*m_pConnection, stdstrPrepStmtName);
+        work pqxxXaction(*m_connectionInThread.connection(), stdstrPrepStmtName);
 		prepare::invocation pqxxInvocation = pqxxXaction.prepared(stdstrPrepStmtName);
 		
 		if(dmlType == dmlUpdate)
@@ -1733,11 +1746,11 @@ bool KPGDataTable::runDml(EDmlType dmlType)
 					if((text(m_editedRow, currentCol) == QString::null) 
 					|| text(m_editedRow, currentCol).isEmpty()) continue;
 					
-					bool bSuccess = m_pConnection->setInvocationValue(pqxxInvocation, m_listTableColumns[currentCol].typName(), text(m_editedRow, currentCol));
+					bool bSuccess = m_connectionInThread.connection()->setInvocationValue(pqxxInvocation, m_listTableColumns[currentCol].typName(), text(m_editedRow, currentCol));
 					if(!bSuccess)
 					{
 						setCurrentCell(m_editedRow, currentCol);
-						m_pConnection->unprepare(stdstrPrepStmtName);
+						m_connectionInThread.connection()->unprepare(stdstrPrepStmtName);
 						throw PGSTD::runtime_error(i18n("Conversion for column %1 failed !").arg(m_listTableColumns[currentCol].name()));
 					}
 				}
@@ -1778,7 +1791,7 @@ bool KPGDataTable::runDml(EDmlType dmlType)
 						else
 						{
 							kdDebug() << k_funcinfo "Uncovered datatype: " <<  m_listTableColumns[currentCol].typName() << ", " << m_listTableColumns[currentCol].name() << endl;	
-							m_pConnection->unprepare(stdstrPrepStmtName);
+							m_connectionInThread.connection()->unprepare(stdstrPrepStmtName);
 							return false;
 						}
 					}
@@ -1786,11 +1799,11 @@ bool KPGDataTable::runDml(EDmlType dmlType)
 				}
 				else
 				{
-					bool bSuccess = m_pConnection->setInvocationValue(pqxxInvocation, m_listTableColumns[currentCol].typName(), text(m_editedRow, currentCol));
+					bool bSuccess = m_connectionInThread.connection()->setInvocationValue(pqxxInvocation, m_listTableColumns[currentCol].typName(), text(m_editedRow, currentCol));
 					if(!bSuccess)
 					{
 						setCurrentCell(m_editedRow, currentCol);
-						m_pConnection->unprepare(stdstrPrepStmtName);
+						m_connectionInThread.connection()->unprepare(stdstrPrepStmtName);
 						throw PGSTD::runtime_error(i18n("Conversion failed !"));
 					}
 				}
@@ -1812,7 +1825,7 @@ bool KPGDataTable::runDml(EDmlType dmlType)
 		pqxxXaction.commit();
 		
 		bNeedUnprepare = false;      
-		m_pConnection->unprepare(stdstrPrepStmtName);
+		m_connectionInThread.connection()->unprepare(stdstrPrepStmtName);
 		
 		
         ((QWidget *) parent())->setCursor(KCursor::arrowCursor());
@@ -1829,7 +1842,7 @@ bool KPGDataTable::runDml(EDmlType dmlType)
 	{
 		try
 	    {	
-	     	m_pConnection->unprepare(stdstrPrepStmtName); 
+	     	m_connectionInThread.connection()->unprepare(stdstrPrepStmtName); 
 	    }
 	    catch (const std::exception &e)
 		{	
@@ -1904,7 +1917,7 @@ pqxx::largeobject KPGDataTable::getLargeObject(int nRow, int nCol, std::string &
 	try
 	{
 		// Select LOB
-		pqxx::prepare::declaration pqxxPrepDecl = m_pConnection->prepare(stdstrPrepStmtName, strSql);
+		pqxx::prepare::declaration pqxxPrepDecl = m_connectionInThread.connection()->prepare(stdstrPrepStmtName, strSql);
 		bNeedUnprepare = true;
 		
 		// Add declaring parameters to prepared statements - primary key fields
@@ -1923,7 +1936,7 @@ pqxx::largeobject KPGDataTable::getLargeObject(int nRow, int nCol, std::string &
 					
 		// And unprepare it
 		bNeedUnprepare = false;
-		m_pConnection->unprepare(stdstrPrepStmtName);
+		m_connectionInThread.connection()->unprepare(stdstrPrepStmtName);
 		
 		// Check query result - one row, one column
 		unsigned int nTotalRows = pqxxResult.size();
@@ -1963,7 +1976,7 @@ pqxx::largeobject KPGDataTable::getLargeObject(int nRow, int nCol, std::string &
 	{
 		if(bNeedUnprepare)
 		{
-			m_pConnection->unprepare(stdstrPrepStmtName);
+			m_connectionInThread.connection()->unprepare(stdstrPrepStmtName);
 		}
 		
 		kdError() << k_funcinfo << e.what() << endl;
@@ -2017,7 +2030,7 @@ pqxx::largeobject KPGDataTable::getLargeObject(int nRow, int nCol, std::string &
 		kdDebug() << strSql << endl;
 		
 		// ---
-		pqxx::prepare::declaration pqxxPrepDecl = m_pConnection->prepare(stdstrPrepStmtName, strSql);
+		pqxx::prepare::declaration pqxxPrepDecl = m_connectionInThread.connection()->prepare(stdstrPrepStmtName, strSql);
 		
 		bNeedUnprepare = true;
 		
@@ -2038,7 +2051,7 @@ pqxx::largeobject KPGDataTable::getLargeObject(int nRow, int nCol, std::string &
 					
 		// And unprepare it
 		bNeedUnprepare = false;
-		m_pConnection->unprepare(stdstrPrepStmtName);
+		m_connectionInThread.connection()->unprepare(stdstrPrepStmtName);
 	
 		return true;
 	}
@@ -2046,7 +2059,7 @@ pqxx::largeobject KPGDataTable::getLargeObject(int nRow, int nCol, std::string &
 	{
 		if(bNeedUnprepare)
 		{
-			m_pConnection->unprepare(stdstrPrepStmtName);
+			m_connectionInThread.connection()->unprepare(stdstrPrepStmtName);
 		}
 		
 		kdError() << k_funcinfo << e.what() << endl;
@@ -2072,9 +2085,9 @@ bool KPGDataTable::setLargeObject(pqxx::largeobject &pqxxLargeObject, int nRow,
 	try
 	{
 		// Update LOB
-		pqxx::prepare::declaration pqxxPrepDecl = m_pConnection->prepare(stdstrPrepStmtName, strSql);
+		pqxx::prepare::declaration pqxxPrepDecl = m_connectionInThread.connection()->prepare(stdstrPrepStmtName, strSql);
 		
-		m_pConnection->setPrepareDeclaration(pqxxPrepDecl, m_listTableColumns[nCol].typName());
+		m_connectionInThread.connection()->setPrepareDeclaration(pqxxPrepDecl, m_listTableColumns[nCol].typName());
 		bNeedUnprepare = true;
 		
 		// Add declaring parameters to prepared statements - primary key fields
@@ -2127,7 +2140,7 @@ bool KPGDataTable::setLargeObject(pqxx::largeobject &pqxxLargeObject, int nRow,
 					
 		// And unprepare it
 		bNeedUnprepare = false;
-		m_pConnection->unprepare(stdstrPrepStmtName);
+		m_connectionInThread.connection()->unprepare(stdstrPrepStmtName);
 	
 		return true;
 	}
@@ -2135,7 +2148,7 @@ bool KPGDataTable::setLargeObject(pqxx::largeobject &pqxxLargeObject, int nRow,
 	{
 		/*if(bNeedUnprepare)
 		{
-			m_pConnection->unprepare(stdstrPrepStmtName);
+			m_connectionInThread.connection()->unprepare(stdstrPrepStmtName);
 		} L.V. cause exception: current TX is aborted */
 		
 		kdError() << k_funcinfo << e.what() << endl;
@@ -2147,7 +2160,7 @@ bool KPGDataTable::setLargeObject(pqxx::largeobject &pqxxLargeObject, int nRow,
 void KPGDataTable::findFirst(QStringList &listOfSearchHistory)
 {
 	// If current row is changed, commit changed row to DB
-    if((m_state == stateUpdate) || (m_state == stateInsert))
+    if((m_state == update) || (m_state == insert))
     {
     	if(commitChanges() == false) return;
     }
@@ -2196,7 +2209,7 @@ void KPGDataTable::findNext()
 void KPGDataTable::slotFindNext()
 {
 	// If current row is changed, commit changed row to DB
-    if((m_state == stateUpdate) || (m_state == stateInsert))
+    if((m_state == update) || (m_state == insert))
     {
     	if(commitChanges() == false) return;
     }
@@ -2298,7 +2311,7 @@ bool KPGDataTable::setLargeObject(pqxx::largeobject &pqxxLargeObject, int nRow,
     const std::string prepStmtName = "test";
     ASSERT(myStr[myStr.size() - 1] == '.');
   
-    pqxx::prepare::declaration D = m_pConnection->prepare(prepStmtName, "INSERT INTO pqxxbin VALUES ($1)");
+    pqxx::prepare::declaration D = m_connectionInThread.connection()->prepare(prepStmtName, "INSERT INTO pqxxbin VALUES ($1)");
     D("bytea", pqxx::prepare::treat_binary);
   
     prepare::invocation I = T.prepared(prepStmtName);
