@@ -12,7 +12,7 @@
 #ifndef KPGDOMAINCONSTRAINTSFOLDER_H
 #define KPGDOMAINCONSTRAINTSFOLDER_H
 
-#include "kpgtreeitem.h"
+#include "kpgitemsfolder.h"
 
 class KPGDomain;
 
@@ -22,7 +22,7 @@ class KPGDomain;
   *
   * @author Lumir Vanek
   */
-class KPGDomainConstraintsFolder : public KPGTreeItem
+class KPGDomainConstraintsFolder : public KPGItemsFolder
 {
 public:
     KPGDomainConstraintsFolder(KPGDomain *);
