@@ -15,12 +15,12 @@
 #include <kmdichildview.h>
 #include <kparts/factory.h> // KPart Factory
 
+#include "kpgdebugger.h"
+
 class KXMLGUIFactory;
 
 class QBoxLayout;
 class KPoGreView;
-class KPGDebugger;
-class KPGConnection;
 class KPGFunction;
 
 
@@ -33,7 +33,7 @@ class KPGDebuggerChildView : public KMdiChildView
 {
 	Q_OBJECT
 public:
-    KPGDebuggerChildView(KPoGreView *, KParts::Factory *, KXMLGUIFactory *, KPGConnection *, const QString &, KPGFunction *);
+	KPGDebuggerChildView(KPoGreView *, KParts::Factory *, KXMLGUIFactory *, const PGSTD::string& , const QString &, KPGFunction *);
     ~KPGDebuggerChildView();
 
     KPGDebugger* getDebugger() const { return m_pDebugger; }
