@@ -16,6 +16,7 @@
 #include <qwidgetstack.h> 
 #include <qtextcodec.h>
 #include <qcheckbox.h>
+#include <qtimer.h>
 
 // include files for KDE
 #include <klocale.h>
@@ -26,12 +27,12 @@
 #include <kcombobox.h>
 #include <kfinddialog.h>
 #include <kfind.h>
+#include <kiconloader.h>
 
 // application specific includes
 #include "../kpgutil.h"
 #include "../kpogreview.h"
 #include "../kpgconfiguration.h"
-#include "../DbObjects/kpgconnection.h"
 #include "../DbObjects/kpgdatabase.h"
 #include "../DbObjects/kpgfunction.h"
 #include "../kpgsqldialog.h"
@@ -39,6 +40,7 @@
 #include "kpgexecutorchildview.h"
 
 #define NUM_OF_RECORDS_PER_PAGE 500 // How many records are loaded to result table 
+#define UPDATE_TIMER_INTERVAL 1000 // 1 sec for updatiing code completion
 
 #define COL_NAME 0
 #define COL_TYPE_NAME 1
@@ -48,23 +50,28 @@
 KPGExecutor::KPGExecutor(KPGExecutorChildView *parent,
 	KPoGreView *pPoGreView,
 	KXMLGUIFactory *pXmlGuiFactory,
-	KPGConnection * pConnection, 
+ 	const PGSTD::string& strConnectionOptions,
 	const QString & strNamespaceName, 
-	KPGFunction *pFunction)  // TODO passing pointer is dangerous, function may be dropped !
+	KPGFunction *pFunction)
 	: 
 	KXMLGUIClient(pPoGreView),
 	KPGExecutorBase(parent, "Executor"),
  	m_pFind(0)
 {
-	m_pConnection = pConnection;
-	m_strNamespaceName = strNamespaceName;
-	m_strFunctionName = pFunction->text(0);
-	
 	// Setup GUI
 	setXMLFile("kpgexecutor.rc", true);
 	m_pXmlGuiFactory = pXmlGuiFactory;
 	m_bIsAddedToGuiFactory = false;
-
+	
+	// Initialize members
+	m_strConnectionOptions = strConnectionOptions;
+	m_strNamespaceName = strNamespaceName;
+	m_strFunctionName = pFunction->text(0);
+	m_bReturnSet = pFunction->returnSet();
+	m_nTotalRows = 0;
+	m_nTotalCols = 0;
+	m_nFetchedRows = 0;
+	
 	//-----------------------------------------------------------------
 	// Executor actions       
 	m_pActExecute = new KAction(i18n("Execute"), "exec", Key_F8, this, SLOT(slotExecute()), actionCollection(), "executor_execute");
@@ -94,6 +101,10 @@ KPGExecutor::KPGExecutor(KPGExecutorChildView *parent,
     //-----------------------------------------------------------------
     connect(m_pTableResult, SIGNAL(contextMenuRequested(int, int, const QPoint &)), this, SLOT(slotContextMenuRequested(int, int, const QPoint &)));
     
+	// Setup tab icons
+	m_pTabWidget->setTabIconSet(pTabResult, QIconSet(QPixmap(SmallIcon("view_text"))));
+	m_pTabWidget->setTabIconSet(pTabTextResult, QIconSet(QPixmap(SmallIcon("openterm"))));
+	
     //-----------------------------------------------------------------
 	// Make own copy of arguments info
 	m_listArguments = pFunction->listArguments();
@@ -122,18 +133,35 @@ KPGExecutor::KPGExecutor(KPGExecutorChildView *parent,
 			else if((*cit).mode() == "b") m_pTableParameters->setText(nRow, COL_MODE, "INOUT");
 			nRow++;
 		}
+		
+		// We use prepared statement, if function has arguments
+		m_connectionInThread.setOperationType(KPGConnectionInThread::eRunPreparedStatement);
+	}
+	else
+	{
+		m_connectionInThread.setOperationType(KPGConnectionInThread::eRunSql);
 	}
 	
 	m_pTableParameters->setColumnReadOnly(0, true);
 	m_pTableParameters->setColumnReadOnly(1, true);
 	m_pTableParameters->setColumnReadOnly(2, true);
 	
-	m_ConnectionInThread.setEventReceiver(this, &m_pqxxResult);
-	m_ConnectionInThread.setOperationType(KPGConnectionInThread::eRunPreparedStatement);
-	
-	m_nTotalRows = 0;
-	m_nTotalCols = 0;
-	m_nFetchedRows = 0;
+	// Open connection
+	m_connectionInThread.setEventReceiver(this, &m_pqxxResult);
+		
+	try
+	{
+		m_connectionInThread.connectToServer(m_strConnectionOptions);
+		
+		KPGNoticer * pPgNoticer = m_connectionInThread.connection()->kpgNoticer();
+		connect(pPgNoticer, SIGNAL(sigNotice(QString)), this, SLOT(slotProcessNotice(QString)));
+	}
+	catch (const std::exception &e)
+	{
+		kdError() << "Failed to open connection " << e.what() << endl;
+		KMessageBox::sorry(this, e.what());
+		return;
+	}
 	
 	m_pActExecute->setEnabled(true);
     m_pActStop->setEnabled(false);
@@ -143,6 +171,12 @@ KPGExecutor::KPGExecutor(KPGExecutorChildView *parent,
 
 KPGExecutor::~KPGExecutor()
 {
+	KPGNoticer * pPgNoticer = m_connectionInThread.connection()->kpgNoticer();
+	disconnect(pPgNoticer, SIGNAL(sigNotice(QString)), this, SLOT(slotProcessNotice(QString)));
+	
+	// Close connection
+	m_connectionInThread.disconnectFromServer(); // close connection if any
+	
 	if(m_pFind != 0) 
     {
     	disconnect( m_pFind, 0, this, 0);
@@ -261,6 +295,8 @@ void KPGExecutor::executeFunction()
 	m_pTableResult->setNumRows(0);
 	m_pTableResult->setNumCols(0);
 	m_pTextEditResult->clear();
+	
+	
 	m_pTextLabelExecutionTime->setText("");
 	m_pqxxResult.clear(); // free memory
 		
@@ -278,15 +314,11 @@ void KPGExecutor::executeFunction()
 				break;
 	}
 	
-	QString strConectionString( );
-	
-	// Run connection in thread
-	m_ConnectionInThread.disconnectFromServer(); // close connection if any
-	
 	m_pTableParameters->setEnabled(false);
 	m_pComboBoxTransaction->setEnabled(false);
 	//emit sigSetTerminalIcon(this, 1); // red terminal icon
-	((QWidget *) parent())->setCursor(KCursor::waitCursor());
+	
+	m_pTableParameters->setCursor(KCursor::waitCursor());
 		
 	m_pActExecute->setEnabled(false);
     m_pActStop->setEnabled(true);
@@ -294,17 +326,7 @@ void KPGExecutor::executeFunction()
     m_pActFetchAll->setEnabled(false);
     m_pActFindInResult->setEnabled(false); 
     m_pActFindNextInResult->setEnabled(false);
-	
-	try
-	{
-		m_ConnectionInThread.connectToServer(m_pConnection->options());
-	}
-	catch (const std::exception &e)
-    {
-        kdError() << "Failed to open connection " << e.what() << endl;
-        KMessageBox::sorry(this, e.what());
-        return;
-    }
+	m_pTableParameters->setEnabled(false);
 	
 	bool bSuccess = runSql(transType);
 	if(!bSuccess)
@@ -313,6 +335,7 @@ void KPGExecutor::executeFunction()
 		m_pActStop->setEnabled(false);
 		m_pTableParameters->setEnabled(true);
 		m_pComboBoxTransaction->setEnabled(true);
+		m_pTableParameters->setCursor(KCursor::arrowCursor());
 	}
 }
 
@@ -327,40 +350,29 @@ void KPGExecutor::customEvent(QCustomEvent *pEvent)
 	{
 		displayExecutionTime(pQueryResultEvent->executionMiliseconds());   
 		displayResult(); 
-		m_pWidgetStackResults->raiseWidget(0);
+		m_pTabWidget->setCurrentPage(0);
 	}
 	else
 	{
-		m_nTotalRows = 0;
-		m_nTotalCols = 0;
-	
-		if(pQueryResultEvent->error().isEmpty() == false)
-		{
-			m_pTextEditResult->setText(pQueryResultEvent->error());
-		}
-		else
-		{
-			displayExecutionTime(pQueryResultEvent->executionMiliseconds());      
-			
-			if(pQueryResultEvent->connection()->notifications().count() > 0)
-			{
-				m_pTextEditResult->setText(pQueryResultEvent->connection()->notifications().join(""));
-				pQueryResultEvent->connection()->clearNotifications();
-			}
-			else  
-			{
-				m_pTextEditResult->setText(i18n("Operation successfull"));
-			}
-		}
-		m_pWidgetStackResults->raiseWidget(1); 
+		m_pTabWidget->setCurrentPage(1);
 	}
 	
+	
+	if(pQueryResultEvent->error().isEmpty() == false)
+	{
+		m_pTextEditResult->append(pQueryResultEvent->error());
+	}
+	
+	displayExecutionTime(pQueryResultEvent->executionMiliseconds());      
+	m_pTextEditResult->append(i18n("\nOperation finished"));
+	
+	
 	m_pTableParameters->setEnabled(true);
 	m_pComboBoxTransaction->setEnabled(true);
 	//emit sigSetTerminalIcon(this, 2); // blue terminal icon
-	((QWidget *) parent())->setCursor(KCursor::arrowCursor());
+	m_pTableParameters->setCursor(KCursor::arrowCursor());
 	
-	m_ConnectionInThread.wait();
+	m_connectionInThread.wait();
 		
 	m_pActExecute->setEnabled(true);
     m_pActStop->setEnabled(false);
@@ -372,30 +384,41 @@ void KPGExecutor::customEvent(QCustomEvent *pEvent)
 
 void KPGExecutor::stopExecute()
 {
-	if(m_ConnectionInThread.running ())
+	if(m_connectionInThread.running ())
 	{
-		m_ConnectionInThread.terminate();
-		m_ConnectionInThread.wait();
-		m_ConnectionInThread.leaveConnection();
+		m_connectionInThread.terminate();
+		m_connectionInThread.wait();
+		m_connectionInThread.leaveConnection();
 		
 		m_pTextEditResult->setText(i18n("Operation terminated"));
-		m_pWidgetStackResults->raiseWidget(1); 
+		m_pTabWidget->setCurrentPage(1);
 		
-		m_pTableParameters->setEnabled(true);
-		m_pComboBoxTransaction->setEnabled(true);
-		//emit sigSetTerminalIcon(this, 0); // black terminal icon
-		//m_bQueryTextChanged = false;
-		
-		m_pActExecute->setEnabled(true);
-        m_pActStop->setEnabled(false);
-        m_pActFetchNext->setEnabled(false); 
-        m_pActFetchAll->setEnabled(false);
-        		
 		m_pqxxResult.clear(); // free memory
 		m_nTotalRows = 0;
 		m_nTotalCols = 0;
 		
-		((QWidget *) parent())->setCursor(KCursor::arrowCursor());
+		try
+		{
+			m_connectionInThread.connectToServer(m_strConnectionOptions);
+			
+			m_pTableParameters->setEnabled(true);
+			m_pComboBoxTransaction->setEnabled(true);
+			//emit sigSetTerminalIcon(this, 0); // black terminal icon
+			//m_bQueryTextChanged = false;
+		
+			m_pActExecute->setEnabled(true);
+			m_pActStop->setEnabled(false);
+			m_pActFetchNext->setEnabled(false); 
+			m_pActFetchAll->setEnabled(false);
+		}
+		catch (const std::exception &e)
+		{
+			kdError() << "Failed to open connection " << e.what() << endl;
+			KMessageBox::sorry(this, e.what());
+			return;
+		}
+
+		m_pTableParameters->setCursor(KCursor::arrowCursor());
 	} 
 }
 
@@ -455,7 +478,7 @@ void KPGExecutor::displayResult()
 	{
 		for(unsigned int nCol = 0; nCol < m_nTotalCols; nCol++)
 		{
-			QString strValue(m_pConnection->textCodec()->toUnicode(m_pqxxResult[nRow][nCol].c_str()));
+			QString strValue(m_connectionInThread.connection()->textCodec()->toUnicode(m_pqxxResult[nRow][nCol].c_str()));
 			m_pTableResult->setText(nRow, nCol, strValue);
 		}
 		
@@ -490,7 +513,7 @@ void KPGExecutor::fetchNext()
 	{
 		for(unsigned int nCol = 0; nCol < m_nTotalCols; nCol++)
 		{
-			QString strValue(m_pConnection->textCodec()->toUnicode(m_pqxxResult[nRow][nCol].c_str()));
+			QString strValue(m_connectionInThread.connection()->textCodec()->toUnicode(m_pqxxResult[nRow][nCol].c_str()));
 			m_pTableResult->setText(nRow, nCol, strValue);
 		}
 		
@@ -534,7 +557,7 @@ void KPGExecutor::fetchAll()
 	{
 		for(unsigned int nCol = 0; nCol < m_nTotalCols; nCol++)
 		{
-			QString strValue(m_pConnection->textCodec()->toUnicode(m_pqxxResult[nRow][nCol].c_str()));
+			QString strValue(m_connectionInThread.connection()->textCodec()->toUnicode(m_pqxxResult[nRow][nCol].c_str()));
 			m_pTableResult->setText(nRow, nCol, strValue);
 		}
 		
@@ -549,98 +572,112 @@ void KPGExecutor::fetchAll()
 	m_pqxxResult.clear(); // free memory
 }  
 
-// Create prepared statement for SQL SELECT operation
-void KPGExecutor::prepareSelectStatement(const std::string &stdstrPrepStmtName)
-{
-    QString strSql;
-    
-    if(m_pCheckBoxExplain->isChecked())
-    {
-    	strSql.append("EXPLAIN ");
-    
-    	if(m_pCheckBoxAnalyze->isChecked())
-    		strSql.append("ANALYZE ");
-    		
-		if(m_pCheckBoxVerbose->isChecked())
-			strSql.append("VERBOSE ");
-    }
-    
-    strSql.append("SELECT * FROM ");
-    strSql.append(KPGUtil::fullyQualifiedName(m_strNamespaceName, m_strFunctionName));
-            
-    strSql.append("(");        
-    
-    int nRows = m_pTableParameters->numRows();
-    for(int i = 0; i < nRows; i++)
-    {
-    	if(i > 0) strSql.append(", ");
-    	
-    	if((m_pTableParameters->text(i, COL_VALUE) == QString::null) || m_pTableParameters->text(i, COL_VALUE).isEmpty())
-        {
-        	strSql.append("NULL");
-        }
-        else
-        {
-        	strSql.append(QString("$%1").arg(i + 1));
-        }
-    }
-    
-    strSql.append(")"); 
-    
-    kdDebug() << strSql << endl;
-    
-    pqxx::prepare::declaration pqxxPrepDecl = m_ConnectionInThread.connection()->prepare(stdstrPrepStmtName, strSql);
-    
-    // Add declaring parameters to prepared statements
-    for(int i = 0; i < nRows; i++)
-    {
-    	if((m_pTableParameters->text(i, COL_VALUE) != QString::null) && m_pTableParameters->text(i, COL_VALUE).isEmpty() == false)
-        {
-        	m_pConnection->setPrepareDeclaration(pqxxPrepDecl, m_listArguments[i].typName());
-        }
-    }
-}
 
 // Run SQL to execute function on DB server
 bool KPGExecutor::runSql(KPGConnection::ETransType transType)
 {
-	m_ConnectionInThread.setPrepStatementName("S_" + KPGUtil::unspacedName(m_strNamespaceName) + "_" + KPGUtil::unspacedName(m_strFunctionName), transType); 
-
-	try
+	QString strSql;
+    
+	if(m_pCheckBoxExplain->isChecked())
 	{
-		prepareSelectStatement(m_ConnectionInThread.prepStatementName()); 
+		strSql.append("EXPLAIN ");
+    
+		if(m_pCheckBoxAnalyze->isChecked())
+			strSql.append("ANALYZE ");
+    		
+		if(m_pCheckBoxVerbose->isChecked())
+			strSql.append("VERBOSE ");
 	}
-	catch(const std::exception &e)
-	{
-		m_pTextEditResult->setText(e.what());
-		m_pWidgetStackResults->raiseWidget(1); 
-
-		return false;
-	} 
+    
+	strSql.append("SELECT ");
 	
-	//***********************
-	ListArgumentsWithValues listArgumentsWithValues;
-			
-	int currentArg = 0;
-	for(KPGFunction::ListArguments::iterator it = m_listArguments.begin(); it != m_listArguments.end(); ++it)
-	{ 
-		if((m_pTableParameters->text(currentArg, COL_VALUE) == QString::null) 
-				|| m_pTableParameters->text(currentArg, COL_VALUE).isEmpty()) continue;
-					
-		listArgumentsWithValues.append(KPGFunctionArgumentWithValue(currentArg + 1, m_listArguments[currentArg].name(), m_listArguments[currentArg].mode(), m_listArguments[currentArg].typName(), m_pTableParameters->text(currentArg, COL_VALUE)));
+	if(m_bReturnSet)
+	{
+		strSql.append("* FROM ");
+	}
+	
+	strSql.append(KPGUtil::fullyQualifiedName(m_strNamespaceName, m_strFunctionName));
+            
+	strSql.append("(");
+    
+	int nArgs = m_pTableParameters->numRows();
+	for(int i = 0; i < nArgs; i++)
+	{
+		if(i > 0) strSql.append(", ");
+    	
+		if((m_pTableParameters->text(i, COL_VALUE) == QString::null) || m_pTableParameters->text(i, COL_VALUE).isEmpty())
+		{
+			strSql.append("NULL");
+		}
+		else
+		{
+			strSql.append(QString("$%1").arg(i + 1));
+		}
+	}
+    
+	strSql.append(")"); 
+    
+	kdDebug() << strSql << endl;
+	
+	if(nArgs == 0)
+	{
+		m_connectionInThread.setSQL(strSql, transType);
+	}
+	else
+	{
+		QString strStatementName("exec_" + KPGUtil::unspacedName(m_strNamespaceName) + "_" + KPGUtil::unspacedName(m_strFunctionName));
+		if(m_pCheckBoxExplain->isChecked())
+		{
+			strStatementName.prepend("expl_"); // Choose different name for EXPLAIN, to avoid error: Inconsistent redefinition of prep. stmt.
+		}
+		
+		m_connectionInThread.setPrepStatementName(strStatementName, transType);
+	
+		try
+		{
+			pqxx::prepare::declaration pqxxPrepDecl = m_connectionInThread.connection()->prepare(strStatementName, strSql);
+		
+			// Add declaring parameters to prepared statements
+			for(int i = 0; i < nArgs; i++)
+			{
+				if((m_pTableParameters->text(i, COL_VALUE) != QString::null) && m_pTableParameters->text(i, COL_VALUE).isEmpty() == false)
+				{
+					m_connectionInThread.connection()->setPrepareDeclaration(pqxxPrepDecl, m_listArguments[i].typName());
+				}
+			}
+		}
+		catch(const std::exception &e)
+		{
+			m_pTextEditResult->append(e.what());
+			m_pTabWidget->setCurrentPage(1);
+	
+			return false;
+		} 
+		
+		//***********************
+		ListArgumentsWithValues listArgumentsWithValues;
 				
-		currentArg++;
+		int currentArg = 0;
+		for(KPGFunction::ListArguments::iterator it = m_listArguments.begin(); it != m_listArguments.end(); ++it)
+		{ 
+			if((m_pTableParameters->text(currentArg, COL_VALUE) == QString::null) 
+					|| m_pTableParameters->text(currentArg, COL_VALUE).isEmpty()) continue;
+						
+			listArgumentsWithValues.append(KPGFunctionArgumentWithValue(currentArg + 1, m_listArguments[currentArg].name(), m_listArguments[currentArg].mode(), m_listArguments[currentArg].typName(), m_pTableParameters->text(currentArg, COL_VALUE)));
+					
+			currentArg++;
+		}
+		
+		m_connectionInThread.setPrepStatementArgumentValues(listArgumentsWithValues); 
 	}
 	
-	m_ConnectionInThread.setPrepStatementArgumentValues(listArgumentsWithValues); 
-	m_ConnectionInThread.start();
-	
+	m_connectionInThread.start();
 	return true;
 }
 
 void KPGExecutor::slotExplainToggled(bool bToggled)
 {
-	m_pCheckBoxAnalyze->setEnabled(bToggled && m_listArguments.count() == 0);
+	m_pCheckBoxAnalyze->setEnabled(bToggled/* && m_listArguments.count() == 0*/); 
 	m_pCheckBoxVerbose->setEnabled(bToggled);
 }
 
@@ -764,3 +801,10 @@ void KPGExecutor::slotHighlight( const QString &, int, int)
     m_pTableResult->setCurrentCell(m_iRowToSearch, m_iColToSearch);
 }
 
+// Process notice from connection in thread
+void KPGExecutor::slotProcessNotice(QString strNotice)
+{
+	qApp->lock();
+	m_pTextEditResult->append(strNotice);
+	qApp->unlock();
+}
