@@ -52,15 +52,15 @@ KPGDatabasePropPage::KPGDatabasePropPage(QWidget *parent, KPGDatabase *pDatabase
 	m_pTabWidget->setTabIconSet(tabCasts, QIconSet(*KPGTreeItem::m_pIconCast)); 
 	m_pTabWidget->setTabIconSet(tabLanguages, QIconSet(*KPGTreeItem::m_pIconLanguage)); 
 	m_pTabWidget->setTabIconSet(tabSchemas, QIconSet(*KPGTreeItem::m_pIconSchema)); 
-	m_pTabWidget->setTabIconSet(tabStatistics, QIconSet(QPixmap(SmallIcon("ksysguard.png")))); 
+	m_pTabWidget->setTabIconSet(tabStatistics, QIconSet(QPixmap(SmallIcon("ksysguard")))); 
 	
-	m_pButtonRefreshStatistics->setIconSet(QIconSet(QPixmap(BarIcon("reload.png"))));
-	m_pPushButtonRefreshDiskUsage->setIconSet(QIconSet(QPixmap(BarIcon("reload.png"))));
-	m_pButtonRefreshLocks->setIconSet(QIconSet(QPixmap(BarIcon("reload.png"))));
+	m_pButtonRefreshStatistics->setIconSet(QIconSet(QPixmap(BarIcon("reload"))));
+	m_pPushButtonRefreshDiskUsage->setIconSet(QIconSet(QPixmap(BarIcon("reload"))));
+	m_pButtonRefreshLocks->setIconSet(QIconSet(QPixmap(BarIcon("reload"))));
 	
-	m_pTabWidget->setTabIconSet(tabACL, QIconSet(QPixmap(UserIcon("group.png"))));
-	m_pTabWidget->setTabIconSet(tabDiskUsage, QIconSet(QPixmap(UserIcon("disk_usage.png"))));
-	m_pTabWidget->setTabIconSet(tabLocks, QIconSet(QPixmap(UserIcon("lock.png")))); 
+	m_pTabWidget->setTabIconSet(tabACL, QIconSet(QPixmap(UserIcon("group"))));
+	m_pTabWidget->setTabIconSet(tabDiskUsage, QIconSet(QPixmap(UserIcon("disk_usage"))));
+	m_pTabWidget->setTabIconSet(tabLocks, QIconSet(QPixmap(UserIcon("lock")))); 
 
     m_bPageCastsDisplaied = false;
     displayProperties();
@@ -499,13 +499,13 @@ void KPGDatabasePropPage::setACL(const QString &strACL)
 		pItem->setText( 0, (*it).grantee() );
 		pItem->setText( 1, (*it).grantor() );
 		
-		pItem->setPixmap(2, UserIcon((*it).canCreate() ? "box_checked.png" : "box_clear.png"));
-		pItem->setPixmap(3, UserIcon((*it).canCreateTemp() ? "box_checked.png" : "box_clear.png"));
+		pItem->setPixmap(2, UserIcon((*it).canCreate() ? "box_checked" : "box_clear"));
+		pItem->setPixmap(3, UserIcon((*it).canCreateTemp() ? "box_checked" : "box_clear"));
 			
 		if((*it).canPassGrantToOther())
 		{  
-		pItem->setPixmap(4, UserIcon((*it).canGrantCreate() ? "box_checked.png" : "box_clear.png"));
-		pItem->setPixmap(5, UserIcon((*it).canGrantCreateTemp() ? "box_checked.png" : "box_clear.png")); 
+		pItem->setPixmap(4, UserIcon((*it).canGrantCreate() ? "box_checked" : "box_clear"));
+		pItem->setPixmap(5, UserIcon((*it).canGrantCreateTemp() ? "box_checked" : "box_clear")); 
 		}
 	} 
 }
@@ -527,22 +527,22 @@ void KPGDatabasePropPage::slotAclListViewClicked(QListViewItem *pItem, const QPo
 				break;
 			
 			case 2:
-				pItem->setPixmap(2, UserIcon((*it).toggleCreate() ? "box_checked.png" : "box_clear.png"));
+				pItem->setPixmap(2, UserIcon((*it).toggleCreate() ? "box_checked" : "box_clear"));
 				break;
 		
 			case 3:
-				pItem->setPixmap(3, UserIcon((*it).toggleCreateTemp() ? "box_checked.png" : "box_clear.png"));
+				pItem->setPixmap(3, UserIcon((*it).toggleCreateTemp() ? "box_checked" : "box_clear"));
 				break;
 			
 			case 4:
 				if((*it).canPassGrantToOther())
-				pItem->setPixmap(4, UserIcon((*it).toggleGrantCreate() ? "box_checked.png" : "box_clear.png"));
+				pItem->setPixmap(4, UserIcon((*it).toggleGrantCreate() ? "box_checked" : "box_clear"));
 				
 				break;
 			
 			case 5:
 				if((*it).canPassGrantToOther())
-				pItem->setPixmap(5, UserIcon((*it).toggleGrantCreateTemp() ? "box_checked.png" : "box_clear.png"));
+				pItem->setPixmap(5, UserIcon((*it).toggleGrantCreateTemp() ? "box_checked" : "box_clear"));
 				
 				break;
 				
