@@ -142,7 +142,7 @@ KPGPropertyPageChildView::KPGPropertyPageChildView(KPoGreView *pPoGreView,
 	
 	m_pLayout = new QHBoxLayout(this, 0, -1, "layout" );
 	
-	setIcon( SmallIcon("history") );
+	setIcon( SmallIcon("info") );
 	
 	// Setup GUI
 	setXMLFile("kpgproppage.rc", true);
