@@ -49,9 +49,9 @@ KPGTablePropPage::KPGTablePropPage(QWidget *parent, KPGTable *pTable)
 	m_pTabWidget->setTabIconSet(tabConstraints, QIconSet(*KPGTreeItem::m_pIconPrimaryKeyConstr)); 
 	m_pTabWidget->setTabIconSet(tabIndexes, QIconSet(*KPGTreeItem::m_pIconIndex)); 
 	m_pTabWidget->setTabIconSet(tabRules, QIconSet(*KPGTreeItem::m_pIconRule)); m_pTabWidget->setTabIconSet(tabTriggers, QIconSet(*KPGTreeItem::m_pIconTrigger)); 
-	m_pTabWidget->setTabIconSet(tabACL, QIconSet(QPixmap(UserIcon("group.png")))); 
-	m_pTabWidget->setTabIconSet(tabStatistics, QIconSet(QPixmap(SmallIcon("ksysguard.png")))); 
-	m_pButtonRefresh->setIconSet(QIconSet(QPixmap(BarIcon("reload.png")))); 
+	m_pTabWidget->setTabIconSet(tabACL, QIconSet(QPixmap(UserIcon("group")))); 
+	m_pTabWidget->setTabIconSet(tabStatistics, QIconSet(QPixmap(SmallIcon("ksysguard")))); 
+	m_pButtonRefresh->setIconSet(QIconSet(QPixmap(BarIcon("reload")))); 
 	
 	m_bPageColumnsDisplaied = false;
     m_bPageConstraintsDisplaied = false;
@@ -497,23 +497,23 @@ void KPGTablePropPage::setACL(const QString &strACL)
 		pItem->setText( 0, (*it).grantee() );
 		pItem->setText( 1, (*it).grantor() );
 		
-		pItem->setPixmap(2, UserIcon((*it).canSelect() ? "box_checked.png" : "box_clear.png"));
-		pItem->setPixmap(3, UserIcon((*it).canInsert() ? "box_checked.png" : "box_clear.png"));
-		pItem->setPixmap(4, UserIcon((*it).canUpdate() ? "box_checked.png" : "box_clear.png"));
-		pItem->setPixmap(5, UserIcon((*it).canDelete() ? "box_checked.png" : "box_clear.png"));
-		pItem->setPixmap(6, UserIcon((*it).canCreateRule() ? "box_checked.png" : "box_clear.png"));
-		pItem->setPixmap(7, UserIcon((*it).canCreateReference() ? "box_checked.png" : "box_clear.png"));
-		pItem->setPixmap(8, UserIcon((*it).canCreateTrigger() ? "box_checked.png" : "box_clear.png"));
+		pItem->setPixmap(2, UserIcon((*it).canSelect() ? "box_checked" : "box_clear"));
+		pItem->setPixmap(3, UserIcon((*it).canInsert() ? "box_checked" : "box_clear"));
+		pItem->setPixmap(4, UserIcon((*it).canUpdate() ? "box_checked" : "box_clear"));
+		pItem->setPixmap(5, UserIcon((*it).canDelete() ? "box_checked" : "box_clear"));
+		pItem->setPixmap(6, UserIcon((*it).canCreateRule() ? "box_checked" : "box_clear"));
+		pItem->setPixmap(7, UserIcon((*it).canCreateReference() ? "box_checked" : "box_clear"));
+		pItem->setPixmap(8, UserIcon((*it).canCreateTrigger() ? "box_checked" : "box_clear"));
 		
 		if((*it).canPassGrantToOther())
 		{  
-		pItem->setPixmap(9, UserIcon((*it).canGrantSelect() ? "box_checked.png" : "box_clear.png"));
-		pItem->setPixmap(10, UserIcon((*it).canGrantInsert() ? "box_checked.png" : "box_clear.png"));
-		pItem->setPixmap(11, UserIcon((*it).canGrantUpdate() ? "box_checked.png" : "box_clear.png"));
-		pItem->setPixmap(12, UserIcon((*it).canGrantDelete() ? "box_checked.png" : "box_clear.png"));
-		pItem->setPixmap(13, UserIcon((*it).canGrantCreateRule() ? "box_checked.png" : "box_clear.png"));
-		pItem->setPixmap(14, UserIcon((*it).canGrantCreateReference() ? "box_checked.png" : "box_clear.png"));
-		pItem->setPixmap(15, UserIcon((*it).canGrantCreateTrigger() ? "box_checked.png" : "box_clear.png")); 
+		pItem->setPixmap(9, UserIcon((*it).canGrantSelect() ? "box_checked" : "box_clear"));
+		pItem->setPixmap(10, UserIcon((*it).canGrantInsert() ? "box_checked" : "box_clear"));
+		pItem->setPixmap(11, UserIcon((*it).canGrantUpdate() ? "box_checked" : "box_clear"));
+		pItem->setPixmap(12, UserIcon((*it).canGrantDelete() ? "box_checked" : "box_clear"));
+		pItem->setPixmap(13, UserIcon((*it).canGrantCreateRule() ? "box_checked" : "box_clear"));
+		pItem->setPixmap(14, UserIcon((*it).canGrantCreateReference() ? "box_checked" : "box_clear"));
+		pItem->setPixmap(15, UserIcon((*it).canGrantCreateTrigger() ? "box_checked" : "box_clear")); 
 		}
 	} 
 }
@@ -535,72 +535,72 @@ void KPGTablePropPage::slotAclListViewClicked(QListViewItem *pItem, const QPoint
 				break;
 			
 			case 2:
-				pItem->setPixmap(2, UserIcon((*it).toggleSelect() ? "box_checked.png" : "box_clear.png"));
+				pItem->setPixmap(2, UserIcon((*it).toggleSelect() ? "box_checked" : "box_clear"));
 				break;
 		
 			case 3:
-				pItem->setPixmap(3, UserIcon((*it).toggleInsert() ? "box_checked.png" : "box_clear.png"));
+				pItem->setPixmap(3, UserIcon((*it).toggleInsert() ? "box_checked" : "box_clear"));
 				break;
 				
 			case 4:
-				pItem->setPixmap(4, UserIcon((*it).toggleUpdate() ? "box_checked.png" : "box_clear.png"));
+				pItem->setPixmap(4, UserIcon((*it).toggleUpdate() ? "box_checked" : "box_clear"));
 				break;
 				
 			case 5:
-				pItem->setPixmap(5, UserIcon((*it).toggleDelete() ? "box_checked.png" : "box_clear.png"));
+				pItem->setPixmap(5, UserIcon((*it).toggleDelete() ? "box_checked" : "box_clear"));
 				break;
 				
 			case 6:
-				pItem->setPixmap(6, UserIcon((*it).toggleCreateRule() ? "box_checked.png" : "box_clear.png"));
+				pItem->setPixmap(6, UserIcon((*it).toggleCreateRule() ? "box_checked" : "box_clear"));
 				break;         
 				
 			case 7:
-				pItem->setPixmap(7, UserIcon((*it).toggleCreateReference() ? "box_checked.png" : "box_clear.png"));
+				pItem->setPixmap(7, UserIcon((*it).toggleCreateReference() ? "box_checked" : "box_clear"));
 				break;
 				
 			case 8:
-				pItem->setPixmap(8, UserIcon((*it).toggleCreateTrigger() ? "box_checked.png" : "box_clear.png"));
+				pItem->setPixmap(8, UserIcon((*it).toggleCreateTrigger() ? "box_checked" : "box_clear"));
 				break;
 						
 			case 9:
 				if((*it).canPassGrantToOther())
-				pItem->setPixmap(9, UserIcon((*it).toggleGrantSelect() ? "box_checked.png" : "box_clear.png"));
+				pItem->setPixmap(9, UserIcon((*it).toggleGrantSelect() ? "box_checked" : "box_clear"));
 				
 				break;
 				
 			case 10:
 				if((*it).canPassGrantToOther())
-				pItem->setPixmap(10, UserIcon((*it).toggleGrantInsert() ? "box_checked.png" : "box_clear.png"));
+				pItem->setPixmap(10, UserIcon((*it).toggleGrantInsert() ? "box_checked" : "box_clear"));
 				
 				break;
 				
 			case 11:
 				if((*it).canPassGrantToOther())
-				pItem->setPixmap(11, UserIcon((*it).toggleGrantUpdate() ? "box_checked.png" : "box_clear.png"));
+				pItem->setPixmap(11, UserIcon((*it).toggleGrantUpdate() ? "box_checked" : "box_clear"));
 				
 				break;
 				
 			case 12:
 				if((*it).canPassGrantToOther())
-				pItem->setPixmap(12, UserIcon((*it).toggleGrantDelete() ? "box_checked.png" : "box_clear.png"));
+				pItem->setPixmap(12, UserIcon((*it).toggleGrantDelete() ? "box_checked" : "box_clear"));
 				
 				break;
 				
 			case 13:
 				if((*it).canPassGrantToOther())
-				pItem->setPixmap(13, UserIcon((*it).toggleGrantCreateRule() ? "box_checked.png" : "box_clear.png"));
+				pItem->setPixmap(13, UserIcon((*it).toggleGrantCreateRule() ? "box_checked" : "box_clear"));
 				
 				break;         
 				
 			case 14:
 				if((*it).canPassGrantToOther())
-				pItem->setPixmap(14, UserIcon((*it).toggleGrantCreateReference() ? "box_checked.png" : "box_clear.png"));
+				pItem->setPixmap(14, UserIcon((*it).toggleGrantCreateReference() ? "box_checked" : "box_clear"));
 				
 				break;
 				
 			case 15:
 				if((*it).canPassGrantToOther())
-				pItem->setPixmap(15, UserIcon((*it).toggleGrantCreateTrigger() ? "box_checked.png" : "box_clear.png"));
+				pItem->setPixmap(15, UserIcon((*it).toggleGrantCreateTrigger() ? "box_checked" : "box_clear"));
 				
 				break;    
 				
