@@ -33,6 +33,7 @@
 #include <klocale.h>
 #include <kfinddialog.h>
 #include <kfind.h>
+#include <kiconloader.h>
 
 // include files for KatePart
 #include <kate/document.h>  // KatePart document
@@ -72,6 +73,10 @@ KPGQueryResultWindow::KPGQueryResultWindow(KPGQueryResultChildView *parent,
 	m_pXmlGuiFactory = pXmlGuiFactory;
 	m_bIsAddedToGuiFactory = false;
 
+	// Setup tab icons
+	m_pTabWidget->setTabIconSet(pTabResult, QIconSet(QPixmap(SmallIcon("view_text"))));
+	m_pTabWidget->setTabIconSet(pTabTextResult, QIconSet(QPixmap(SmallIcon("openterm"))));
+	
 	//-----------------------------------------------------------------
 	// Query/result actions
 	m_pActRunQuery = new KAction(i18n("&Run query"), "fork", Key_F8, this, SLOT(slotRunQuery()), actionCollection(), "queryresult_run_query");
@@ -154,8 +159,8 @@ KPGQueryResultWindow::KPGQueryResultWindow(KPGQueryResultChildView *parent,
 		
 	connect(m_pTableResult, SIGNAL(contextMenuRequested(int, int, const QPoint &)), this, SLOT(slotContextMenuRequested(int, int, const QPoint &)));
 	
-	m_ConnectionInThread.setEventReceiver(this, &m_pqxxResult);
-	
+	m_connectionInThread.setEventReceiver(this, &m_pqxxResult);
+		
 	m_nTotalRows = 0;
 	m_nTotalCols = 0;
 	m_nFetchedRows = 0;
@@ -563,14 +568,13 @@ void KPGQueryResultWindow::runQuery(KPGDatabase *pDatabase)
 	m_pActFetchNext->setEnabled(false);
   	m_pActFetchAll->setEnabled(false);
   	m_pActFindInResult->setEnabled(false); 
-    m_pActFindNextInResult->setEnabled(false);
-    
-	// Run connection in thread
-	m_ConnectionInThread.disconnectFromServer(); // close connection if any
-	
+    	
 	try
 	{
-		m_ConnectionInThread.connectToServer(pDatabase->connection()->options());
+		m_connectionInThread.connectToServer(pDatabase->connection()->options());
+		KPGNoticer * pPgNoticer = m_connectionInThread.connection()->kpgNoticer();
+		connect(pPgNoticer, SIGNAL(sigNotice(QString)), this, SLOT(slotProcessNotice(QString)));
+		
 	}
 	catch (const std::exception &e)
     {
@@ -593,9 +597,10 @@ void KPGQueryResultWindow::runQuery(KPGDatabase *pDatabase)
     }
     
     strSql.append(editorText());
-    
-	m_ConnectionInThread.setSQL(strSql, transType);
-	m_ConnectionInThread.start();
+	
+    // Run connection in thread
+	m_connectionInThread.setSQL(strSql, transType);
+	m_connectionInThread.start();
 }
 
 void KPGQueryResultWindow::customEvent(QCustomEvent *pEvent)
@@ -614,91 +619,67 @@ void KPGQueryResultWindow::customEvent(QCustomEvent *pEvent)
 	{
 		displayExecutionTime(pQueryResultEvent->executionMiliseconds());   
 		displayResult(); 
-		m_pWidgetStackResults->raiseWidget(0);
+		m_pTabWidget->setCurrentPage(0);
 	}
 	else
 	{
-		m_nTotalRows = 0;
-		m_nTotalCols = 0;
-	
-		if(pQueryResultEvent->error().isEmpty() == false)
-		{
-			QString strErrorText(pQueryResultEvent->error());
-			
-			
-			if(pQueryResultEvent->connection()->notifications().count() > 0)
-			{
-				m_pTextEditResult->setText(pQueryResultEvent->connection()->notifications().join("") + strErrorText);
-				pQueryResultEvent->connection()->clearNotifications();
-			}
-			else
-			{
-				m_pTextEditResult->setText(strErrorText);
-			}
-			
-			
-			if(strErrorText.contains("syntax error at or near") > 0)
-			{
-				// Parse error message and obtain number of character position
-				QRegExp patternNumber = QRegExp("\\d+\n", false);
-				int iPos = patternNumber.search(strErrorText, 0);
-				
-				if(iPos > 0)
-				{
-					QString strNumber = strErrorText.mid(iPos);
-					kdDebug() << "Error at character: " << strNumber << endl;
-					
-					bool bConversionOk;
-					int iErrorPosition = strNumber.toInt(&bConversionOk);
-					
-					if(bConversionOk)
-					{
-						if(iErrorPosition > 1) iErrorPosition--; // 1 based -> 0 based
-						
-						// Place cursor and error mark in editor to error position
-						
-						KTextEditor::EditInterface *pEditIface = KTextEditor::editInterface(m_pKateView->document());
-						
-						KTextEditor::MarkInterface *pMarkIface = KTextEditor::markInterface(m_pKateView->getDoc());
-						
-						unsigned int uiNumLines = pEditIface->numLines();
-												
-						for(unsigned int line = 0; line < uiNumLines; line++)
-						{
-							int iLineLength = pEditIface->lineLength(line);
-							if(iErrorPosition <= iLineLength)
-							{
-								viewCursorInterface(m_pKateView)->setCursorPosition(line, iErrorPosition);
-								pMarkIface->addMark(line, KTextEditor::MarkInterface::Error);
-								
-								break;
-							}
-							else
-							{
-								iErrorPosition -= iLineLength;
-							}
-						}
-					}
-				}
-			}
-		}
-		else
-		{
-			displayExecutionTime(pQueryResultEvent->executionMiliseconds());      
-			
-			if(pQueryResultEvent->connection()->notifications().count() > 0)
-			{
-				m_pTextEditResult->setText(pQueryResultEvent->connection()->notifications().join(""));
-				pQueryResultEvent->connection()->clearNotifications();
-			}
-			else  
-			{
-				m_pTextEditResult->setText(i18n("Operation successfull, no rows returned"));
-			}
-		}
-		m_pWidgetStackResults->raiseWidget(1); 
+		m_pTabWidget->setCurrentPage(1);
 	}
 	
+	if(pQueryResultEvent->error().isEmpty() == false)
+	{
+		m_pTextEditResult->append(pQueryResultEvent->error());
+			
+		QString strErrorText(pQueryResultEvent->error());	
+		if(strErrorText.contains("syntax error at or near") > 0)
+		{
+			// Parse error message and obtain number of character position
+			QRegExp patternNumber = QRegExp("\\d+\n", false);
+			int iPos = patternNumber.search(strErrorText, 0);
+				
+			if(iPos > 0)
+			{
+				QString strNumber = strErrorText.mid(iPos);
+				kdDebug() << "Error at character: " << strNumber << endl;
+					
+				bool bConversionOk;
+				int iErrorPosition = strNumber.toInt(&bConversionOk);
+					
+				if(bConversionOk)
+				{
+					if(iErrorPosition > 1) iErrorPosition--; // 1 based -> 0 based
+						
+					// Place cursor and error mark in editor to error position
+						
+					KTextEditor::EditInterface *pEditIface = KTextEditor::editInterface(m_pKateView->document());
+						
+					KTextEditor::MarkInterface *pMarkIface = KTextEditor::markInterface(m_pKateView->getDoc());
+						
+					unsigned int uiNumLines = pEditIface->numLines();
+												
+					for(unsigned int line = 0; line < uiNumLines; line++)
+					{
+						int iLineLength = pEditIface->lineLength(line);
+						if(iErrorPosition <= iLineLength)
+						{
+							viewCursorInterface(m_pKateView)->setCursorPosition(line, iErrorPosition);
+							pMarkIface->addMark(line, KTextEditor::MarkInterface::Error);
+								
+							break;
+						}
+						else
+						{
+							iErrorPosition -= iLineLength;
+						}
+					} // for
+				} // if(bConversionOk)
+			} // if(iPos > 0)
+		} // if(strErrorText.contains("syntax error at or near") > 0)
+	}
+	
+	displayExecutionTime(pQueryResultEvent->executionMiliseconds());      		
+	m_pTextEditResult->append(i18n("\nOperation finished"));
+	
 	m_pKateView->setEnabled(true);
 	m_pKateView->setFocus();
 	m_pComboBoxServer->setEnabled(true);
@@ -707,7 +688,12 @@ void KPGQueryResultWindow::customEvent(QCustomEvent *pEvent)
 	emit sigSetTerminalIcon(this, 2); // blue terminal icon
 	((QWidget *) parent())->setCursor(KCursor::arrowCursor());
 	
-	m_ConnectionInThread.wait();
+	m_connectionInThread.wait();
+	
+	KPGNoticer * pPgNoticer = m_connectionInThread.connection()->kpgNoticer();
+	disconnect(pPgNoticer, SIGNAL(sigNotice(QString)), this, SLOT(slotProcessNotice(QString)));
+	
+	m_connectionInThread.disconnectFromServer(); // close connection
 		
 	m_pActRunQuery->setEnabled(true);
 	m_pActStopQuery->setEnabled(false);
@@ -718,14 +704,18 @@ void KPGQueryResultWindow::customEvent(QCustomEvent *pEvent)
 
 void KPGQueryResultWindow::stopQuery()
 {
-	if(m_ConnectionInThread.running ())
+	if(m_connectionInThread.running ())
 	{
-		m_ConnectionInThread.terminate();
-		m_ConnectionInThread.wait();
-		m_ConnectionInThread.leaveConnection();
+		m_connectionInThread.terminate();
+		m_connectionInThread.wait();
+		
+		KPGNoticer * pPgNoticer = m_connectionInThread.connection()->kpgNoticer();
+		disconnect(pPgNoticer, SIGNAL(sigNotice(QString)), this, SLOT(slotProcessNotice(QString)));
+		
+		m_connectionInThread.leaveConnection();
 		
 		m_pTextEditResult->setText(i18n("Operation terminated"));
-		m_pWidgetStackResults->raiseWidget(1); 
+		m_pTabWidget->setCurrentPage(1);
 		
 		m_pKateView->setEnabled(true);
 		m_pComboBoxServer->setEnabled(true);
@@ -742,7 +732,7 @@ void KPGQueryResultWindow::stopQuery()
 		m_nTotalRows = 0;
 		m_nTotalCols = 0;
 			
-		((QWidget *) parent())->setCursor(KCursor::arrowCursor());
+		//((QWidget *) parent())->setCursor(KCursor::arrowCursor());
 	} 
 }
 
@@ -874,7 +864,7 @@ void KPGQueryResultWindow::fetchAll()
 		}
 	}
 	
-	((QWidget *) parent())->setCursor(KCursor::waitCursor());
+	//((QWidget *) parent())->setCursor(KCursor::waitCursor());
 	m_pTableResult->setNumRows(nRows + m_pTableResult->numRows());
 	
 	// Data
@@ -890,7 +880,7 @@ void KPGQueryResultWindow::fetchAll()
 		m_nFetchedRows++;
 	}
 	
-	((QWidget *) parent())->setCursor(KCursor::arrowCursor());
+	//((QWidget *) parent())->setCursor(KCursor::arrowCursor());
 	
 	m_pActFetchNext->setEnabled(false);
 	m_pActFetchAll->setEnabled(false);
@@ -1042,10 +1032,18 @@ void KPGQueryResultWindow::slotHighlight( const QString &, int, int)
     m_pTableResult->setCurrentCell(m_iRowToSearch, m_iColToSearch);
 }
 
-// Re-route signal from KPGSqlEdit
-void KPGQueryResultWindow::slotRequestTableColumnsListsForCodeCompletion(pqxx::oid oidTable)
+// Process notice from connection in thread
+void KPGQueryResultWindow::slotProcessNotice(QString strNotice)
 {
-	emit sigRequestTableColumnsListsForCodeCompletion(this, oidTable);
+	qApp->lock();
+	m_pTextEditResult->append(strNotice);
+	qApp->unlock();
+}
+
+// Re-route signal from KPGSqlEdit
+void KPGQueryResultWindow::slotRequestTableColumnsListsForCodeCompletion(const KPGOidNameAliases *pOnaTable)
+{
+	emit sigRequestTableColumnsListsForCodeCompletion(this, pOnaTable);
 }
 
 // Re-route signal from KPGSqlEdit
@@ -1055,9 +1053,9 @@ void KPGQueryResultWindow::slotRequestSchemaChildsListsForCodeCompletion(pqxx::o
 }
 
 // Re-route signal from KPGSqlEdit
-void KPGQueryResultWindow::slotRequestFunctionReturnTypeAttributesListsForCodeCompletion(pqxx::oid oidFunction)
+void KPGQueryResultWindow::slotRequestFunctionReturnTypeAttributesListsForCodeCompletion(const KPGOidNameAliases * pOnaFunction)
 {
-	emit sigRequestFunctionReturnTypeAttributesListsForCodeCompletion(this, oidFunction);
+	emit sigRequestFunctionReturnTypeAttributesListsForCodeCompletion(this, pOnaFunction);
 }
 
 // Fired from m_pUpdateCodeCompletionListTimer. Updates aliases 
@@ -1091,15 +1089,15 @@ void KPGQueryResultWindow::slotCompletionAborted()
 // Return the string to complete (the letters behind the cursor)
 QString KPGQueryResultWindow::word()
 {
-	uint cline, ccol;
-	viewCursorInterface(m_pKateView)->cursorPositionReal(&cline, &ccol);
-	if (! ccol) return QString::null; // no word
+	uint uiLine, uiCol;
+	viewCursorInterface(m_pKateView)->cursorPositionReal(&uiLine, &uiCol);
+	if (! uiCol) return QString::null; // no word
 	
 	KTextEditor::EditInterface *pEditIface = KTextEditor::editInterface(m_pKateView->document());
 	
 	//m_RegExp.setWildcard(false);
 	m_RegExp.setPattern( "\\b(\\w+)$" );
-	if ( m_RegExp.searchRev(pEditIface->text( cline, 0, cline, ccol )) < 0 )
+	if ( m_RegExp.searchRev(pEditIface->text( uiLine, 0, uiLine, uiCol )) < 0 )
 		return QString::null; // no word
 		
 	kdDebug() << m_RegExp.cap( 1 ) << endl;
@@ -1138,14 +1136,6 @@ void KPGQueryResultWindow::setListOfObjectsForCodeCompletion(const KPGOidNameLis
     
     // Sort list of code completions
     m_listOfCodeCompletionObjects.sort();
-    
-    // Create list of all completions
-    /*for(KPGOidNameAliasesList::const_iterator cit = m_listOfCodeCompletionObjects.begin(); cit != m_listOfCodeCompletionObjects.end(); ++cit)
-	{
-        KTextEditor::CompletionEntry e;
-    	e.text = ((*cit).name());
-        m_completionList.append(e);
-    }*/
                 
     m_bCodeCompletionListUpdated = false;
     if(m_pUpdateCodeCompletionListTimer) m_pUpdateCodeCompletionListTimer->start( UPDATE_TIMER_INTERVAL ); 
@@ -1165,14 +1155,6 @@ void KPGQueryResultWindow::setListOfSchemaChildsForCodeCompletion(const KPGOidNa
     
     // Sort list of code completions
     m_listOfCodeCompletionSchemaChilds.sort();
-    
-    // Create list of all completions
-    /*for(KPGOidNameList::const_iterator cit = m_listOfCodeCompletionSchemaChilds.begin(); cit != m_listOfCodeCompletionSchemaChilds.end(); ++cit)
-	{
-        KTextEditor::CompletionEntry e;
-    	e.text = ((*cit).name());
-        m_completionList.append(e);
-    }*/
                 
     m_bCodeCompletionListUpdated = false;
     if(m_pUpdateCodeCompletionListTimer) m_pUpdateCodeCompletionListTimer->start( UPDATE_TIMER_INTERVAL ); 
@@ -1182,24 +1164,12 @@ void KPGQueryResultWindow::setListOfSchemaChildsForCodeCompletion(const KPGOidNa
 void KPGQueryResultWindow::clearListOfObjectsForCodeCompletion()
 {
 	m_listOfCodeCompletionObjects.clear();
-    // @deprecated m_completionList.clear();
-    
-    // Add SQL keywords to list
-    /*  @deprecated QStringList strKeyWords = KPGSyntaxHighlighter::listOfKeyWords();
-    
-    for(QStringList::const_iterator cit = strKeyWords.begin(); cit != strKeyWords.end(); ++cit)
-    {
-    	KTextEditor::CompletionEntry e;
-    	e.text = (*cit);
-        m_completionList.append(e);
-    }*/
 }
 
 // Clear list of schema childs for code completion
 void KPGQueryResultWindow::clearListOfSchemaChildsForCodeCompletion()
 {
     m_listOfCodeCompletionSchemaChilds.clear();
-    // @deprecated m_completionList.clear();
 }
 
 // Set list of table columns/type attributes for code completion
@@ -1211,10 +1181,6 @@ void KPGQueryResultWindow::setListOfColumnsForCodeCompletion(const KPGListTableC
     for(KPGListTableColumns::const_iterator cit = listOfTableColumns.begin(); cit != listOfTableColumns.end(); ++cit)
     {
         m_listOfCodeCompletionColumns.append(*cit);
-        
-        /* @deprecated KTextEditor::CompletionEntry e;
-    	e.text = ((*cit).name());
-        m_completionList.append(e);*/
     }
 }
 
@@ -1222,7 +1188,6 @@ void KPGQueryResultWindow::setListOfColumnsForCodeCompletion(const KPGListTableC
 void KPGQueryResultWindow::clearListOfColumnsForCodeCompletion()
 {
 	m_listOfCodeCompletionColumns.clear();
-    // @deprecated m_completionList.clear();
 }
 
 // Filters events - for watching Ctrl+SPACE and others keys, that starts code completion
@@ -1276,7 +1241,13 @@ bool KPGQueryResultWindow::eventFilter(QObject *pObject, QEvent *pEvent)
 void KPGQueryResultWindow::updateCtrlSpaceCompletion()
 {
     QString strWord(word());
-		
+	
+	if(wordBeforeDot().endsWith(".")) // If Ctrl+Space is pressed after dot, run perion completion instead
+	{
+		updatePeriodCompletion();
+		return;
+	}
+	
 	QStringList strKeyWords = KPGSyntaxHighlighter::listOfKeyWords();
     QValueList<KTextEditor::CompletionEntry> listMatches;
     for(QStringList::const_iterator cit = strKeyWords.begin(); cit != strKeyWords.end(); ++cit)
@@ -1295,21 +1266,35 @@ void KPGQueryResultWindow::updateCtrlSpaceCompletion()
 			
 			switch((*cit).type())
 			{
+				case KPGTreeItem::nodeSchema:  
+					e.comment = i18n("Schema ");
+					e.comment += (*cit).name();	
+					break;
+
 				case KPGTreeItem::nodeTable:  
-						e.comment = i18n("Table");
-						break;
+					e.comment = i18n("Table ");
+					e.comment += (*cit).fqName();
+					break;
+						
+				case KPGTreeItem::nodeView:  
+					e.comment = i18n("View ");
+					e.comment += (*cit).fqName();
+					break;
 													   	
 				case KPGTreeItem::nodeFunction:  
-						e.comment = i18n("Function");
-						e.postfix = (*cit).argumentTypes();
-						break;
+					e.comment = i18n("Function ");
+					e.comment += (*cit).returnTypName() + " ";
+					e.comment += (*cit).fqName();
+					e.comment += (*cit).argumentTypes();
+					e.postfix = (*cit).argumentTypes();
+					break;
 													   						   	
 				default: break;							   						   	
 			}
 			
 			if(((*cit).description() != QString::null) && ((*cit).description().length() > 0))
 			{
-				e.comment += ": " + (*cit).description();
+				e.comment += "\n" + (*cit).description();
 			}
 			
 			listMatches.append(e);
@@ -1334,18 +1319,20 @@ void KPGQueryResultWindow::updatePeriodCompletion()
         }
         
         kdDebug() << k_funcinfo << " for: " << strWordWithoutDot << endl;
-		
-		// Uncompleted word is table or alias
-		      
-        // Find table or function, 1st by name, 2nd by alias
+						      
+        // Find schema, table or function, 1st by name, 2nd by alias
         const KPGOidNameAliases * pOidNameAliases = m_listOfCodeCompletionObjects.getConstItemByName(strWordWithoutDot); 
         if(pOidNameAliases == 0)
         {
             pOidNameAliases = m_listOfCodeCompletionObjects.getConstItemByAlias(strWordWithoutDot); 
         }
-            
-        if(pOidNameAliases && (pOidNameAliases->type() == KPGTreeItem::nodeSchema))
+        
+		if(pOidNameAliases == 0) return;
+    
+        if(pOidNameAliases->type() == KPGTreeItem::nodeSchema)
         {
+			// Uncompleted word is table or function or view
+			
             emit sigRequestSchemaChildsListsForCodeCompletion(this, pOidNameAliases->oid());
             QValueList<KTextEditor::CompletionEntry> listMatches;
                 
@@ -1354,39 +1341,47 @@ void KPGQueryResultWindow::updatePeriodCompletion()
                 KTextEditor::CompletionEntry e;
 				//e.type = "";
 				e.text = (*cit).name();
-				//e.comment = (*i).comment;
 				//e.userdata = (*i).userdata;
 					
 				switch((*cit).type())
 				{
 					case KPGTreeItem::nodeTable:  
-							e.comment = i18n("Table");
-							break;
+						e.comment = i18n("Table ");
+						e.comment += (*cit).fqName();
+						break;
+							
+					case KPGTreeItem::nodeView:  
+						e.comment = i18n("View ");
+						e.comment += (*cit).fqName();
+						break;
 													   	
 					case KPGTreeItem::nodeFunction:  
-							e.comment = i18n("Function");
-							e.postfix = (*cit).argumentTypes();
-							break;
+						e.comment = i18n("Function ");
+						e.comment += (*cit).returnTypName() + " ";
+						e.comment += (*cit).fqName();
+						e.comment += (*cit).argumentTypes();
+						e.postfix = (*cit).argumentTypes();
+						break;
 													   						   	
 					default: break;					   						   	
 				}
-					
+									
 				if(((*cit).description() != QString::null) && ((*cit).description().length() > 0))
 				{
-					e.comment += ": " + (*cit).description();
+					e.comment += "\n" + (*cit).description();
 				}
 			
 				listMatches.append(e);
             }
                 
             m_eCompletionMode = modeSchemaChilds;
-            updateCompletion(strWordWithoutDot, listMatches);
+            updateCompletion(listMatches);
         }
-        else if(pOidNameAliases && (pOidNameAliases->type() == KPGTreeItem::nodeTable))
+        else if(pOidNameAliases->type() == KPGTreeItem::nodeTable)
         {
           	// Uncompleted word is table column
 		    
-            emit sigRequestTableColumnsListsForCodeCompletion(this, pOidNameAliases->oid());
+            emit sigRequestTableColumnsListsForCodeCompletion(this, pOidNameAliases);
                 
             QValueList<KTextEditor::CompletionEntry> listMatches;
             for(KPGListTableColumns::const_iterator cit = m_listOfCodeCompletionColumns.begin(); cit != m_listOfCodeCompletionColumns.end(); ++cit)
@@ -1399,7 +1394,7 @@ void KPGQueryResultWindow::updatePeriodCompletion()
 					
 				if(((*cit).description() != QString::null) && ((*cit).description().length() > 0))
 				{
-					e.comment += ": " + (*cit).description();
+					e.comment += "\n" + (*cit).description();
 				}
 					
 				listMatches.append(e);
@@ -1408,10 +1403,10 @@ void KPGQueryResultWindow::updatePeriodCompletion()
             m_eCompletionMode = modeTableColumns;
             updateCompletion(listMatches);
         }
-        else if(pOidNameAliases && (pOidNameAliases->type() == KPGTreeItem::nodeFunction))
+        else if((pOidNameAliases->type() == KPGTreeItem::nodeFunction) && (pOidNameAliases->returnSet()))
         {
             // Uncompleted word is function return type column
-            emit sigRequestFunctionReturnTypeAttributesListsForCodeCompletion(this, pOidNameAliases->oid());
+            emit sigRequestFunctionReturnTypeAttributesListsForCodeCompletion(this, pOidNameAliases);
                 
             QValueList<KTextEditor::CompletionEntry> listMatches;
             for(KPGListTableColumns::const_iterator cit = m_listOfCodeCompletionColumns.begin(); cit != m_listOfCodeCompletionColumns.end(); ++cit)
@@ -1419,8 +1414,14 @@ void KPGQueryResultWindow::updatePeriodCompletion()
                 KTextEditor::CompletionEntry e;
 				e.type = "COLUMN";
 				e.text = (*cit).name();
-				e.comment = i18n("Function column");
+				e.comment = (*cit).typName() + i18n(" column");
 				//e.userdata = (*i).userdata;
+
+				if(((*cit).description() != QString::null) && ((*cit).description().length() > 0))
+				{
+					e.comment += "\n" + (*cit).description();
+				}
+
 				listMatches.append(e);
             }
                                                 
@@ -1435,8 +1436,6 @@ void KPGQueryResultWindow::updateCompletion(const QString &strWord, const QValue
 {	
 	if(completionList.count() > 0)
 	{
-		//m_completionList = completionList;
-		
 		KTextEditor::CodeCompletionInterface * pCodeComplIface = KTextEditor::codeCompletionInterface(m_pKateView);
 		
 		pCodeComplIface->showCompletionBox(completionList, strWord.length(), true);
@@ -1452,8 +1451,6 @@ void KPGQueryResultWindow::updateCompletion(const QValueList<KTextEditor::Comple
 {	
 	if(completionList.count() > 0)
 	{
-		//m_completionList = completionList;
-		
 		KTextEditor::CodeCompletionInterface * pCodeComplIface = KTextEditor::codeCompletionInterface(m_pKateView);
 		
 		pCodeComplIface->showCompletionBox(completionList, 0, true);
@@ -1464,6 +1461,20 @@ void KPGQueryResultWindow::updateCompletion(const QValueList<KTextEditor::Comple
 	}
 }
 
+// Insert code snippet
+void KPGQueryResultWindow::insertSnippet(const QString & strText)
+{
+	unsigned int uiLine;
+	unsigned int uiCol;
+	
+	viewCursorInterface(m_pKateView)->cursorPosition(&uiLine, &uiCol);
+	
+	//KTextEditor::EditInterface *pEditIface = KTextEditor::editInterface(m_pKateView->document());
+	
+	editInterface(m_pKateView->document())->insertText(uiLine, uiCol, strText);
+	m_pKateView->setFocus();
+}
+
 // Scan for possible completions, ignoring any dublets
 /*QValueList<KTextEditor::CompletionEntry> KPGQueryResultWindow::allMatches(const QString &word)
 {
