@@ -52,7 +52,7 @@ KPGSqlEdit::KPGSqlEdit(QWidget* pParent, const char* szName)
     for(QStringList::const_iterator cit = strKeyWords.begin(); cit != strKeyWords.end(); ++cit)
     {
         // SQL keywords are identified as nodeUnselected
-        m_listOfCodeCompletionObjects.append(KPGOidName(0, *cit, KPGTreeItem::nodeUnselected, KPGTreeItem::m_pIconNull, QString::null));
+		m_listOfCodeCompletionObjects.append(KPGOidName(0, *cit, QString::null, KPGTreeItem::nodeUnselected, KPGTreeItem::m_pIconNull, QString::null));
     }
 	completionObject()->insertItems(KPGSyntaxHighlighter::listOfKeyWords());
 		
@@ -309,7 +309,7 @@ void KPGSqlEdit::updatePeriodCompletion(bool bShow)
             }
             else if(pOidNameAliases && (pOidNameAliases->type() == KPGTreeItem::nodeFunction))
             {
-                emit sigRequestFunctionReturnTypeAttributesListsForCodeCompletion(pOidNameAliases->oid());
+                emit sigRequestFunctionReturnTypeAttributesListsForCodeCompletion(pOidNameAliases);
                 
                 QStringList strListMatches;
                 for(KPGListTableColumns::const_iterator cit = m_listOfCodeCompletionColumns.begin(); cit != m_listOfCodeCompletionColumns.end(); ++cit)
@@ -582,7 +582,7 @@ void KPGSqlEdit::clearListOfObjectsForCodeCompletion()
     for(QStringList::const_iterator cit = strKeyWords.begin(); cit != strKeyWords.end(); ++cit)
     {
         // SQL keywords are identified as nodeUnselected
-        m_listOfCodeCompletionObjects.append(KPGOidName(0, *cit, KPGTreeItem::nodeUnselected, KPGTreeItem::m_pIconNull, QString::null));
+		m_listOfCodeCompletionObjects.append(KPGOidName(0, *cit, QString::null, KPGTreeItem::nodeUnselected, KPGTreeItem::m_pIconNull, QString::null));
     }
 }
 
