@@ -24,7 +24,7 @@ class KPGConnection;
   */
 class KPG2StepsWizard : public KPG2StepsWizardBase
 {
-Q_OBJECT
+	Q_OBJECT
 public:
     KPG2StepsWizard(QWidget *, const QString &, const QString &, bool = true);
     ~KPG2StepsWizard();
@@ -36,15 +36,25 @@ public:
     KPGConnection * connection() const { return m_pConnection; }
     
 protected:
+	
 	virtual void showPage(QWidget *);
 		
-protected:
-
+private:  
+	
+    // Connection to database
 	KPGConnection *m_pConnection;
-	bool m_bWithTransaction;
 		
-  	/** Syntax highlighter for m_pTextEditSQL */
-  	KPGSyntaxHighlighter *m_pSyntaxHighlighter;
+  	// Syntax highlighter for m_pTextEditSQL
+	KPGSyntaxHighlighter *m_pSyntaxHighlighter;
+	
+	// Noticications list
+	QStringList m_listOfNotifications;
+
+	bool m_bWithTransaction;
+	
+protected slots:
+	// Process notice from connection in thread
+	void slotProcessNotice(QString);
 };
 
 #endif
