@@ -44,15 +44,24 @@ protected:
 protected:
 	QWidget *m_pPageWidget1;
 
-private:	
+private:  
+	
+    // Connection to database
 	KPGConnection *m_pConnection;
-			
-  	/** Syntax highlighter for m_pTextEditSQL */
-  	KPGSyntaxHighlighter *m_pSyntaxHighlighter;
+		
+  	// Syntax highlighter for m_pTextEditSQL
+	KPGSyntaxHighlighter *m_pSyntaxHighlighter;
+	
+	// Noticications list
+	QStringList m_listOfNotifications;
 						
 protected slots:
+	
 	// Enable/disable next button for 1st page
 	void slotEnableNextButton1(bool);
+	
+	// Process notice from connection
+	void slotProcessNotice(QString);
 };
 
 #endif
