@@ -24,7 +24,7 @@ class KPGConnection;
   */
 class KPG4StepsWizard : public KPG4StepsWizardBase
 {
-Q_OBJECT
+	Q_OBJECT
 public:
     KPG4StepsWizard(QWidget *parent = 0, const char *name = 0);
     ~KPG4StepsWizard();
@@ -39,25 +39,36 @@ public:
 	QWidget * pageWidget2() { return m_pPageWidget2; }
 
 protected:
+	
     // Run SQL query - as final Wizard operation
     void runQuery(bool = true);
     			
 protected:
+	
 	QWidget *m_pPageWidget1;
 	QWidget *m_pPageWidget2;
 
 private:  
-    KPGConnection *m_pConnection;
+	
+    // Connection to database
+	KPGConnection *m_pConnection;
 		
-  	/** Syntax highlighter for m_pTextEditSQL */
-  	KPGSyntaxHighlighter *m_pSyntaxHighlighter;
+  	// Syntax highlighter for m_pTextEditSQL
+	KPGSyntaxHighlighter *m_pSyntaxHighlighter;
+	
+	// Noticications list
+	QStringList m_listOfNotifications;
 				
 protected slots:
+	
 	// Enable/disable next button for 1st page
 	void slotEnableNextButton1(bool);
 
 	// Enable/disable next button for 2nd page
 	void slotEnableNextButton2(bool);
+	
+	// Process notice from connection
+	void slotProcessNotice(QString);
 };
 
 #endif
