@@ -1349,7 +1349,7 @@ void KPoGreController::slotDebugFunction()
 	KMessageBox::sorry( m_pView, "Not implemented yet ...", "KPoGre");
     return;
 	
-    m_pView->debugFunction();
+    //m_pView->debugFunction();
     slotStatusMsg(i18n("Ready."));
 }
    
@@ -1666,12 +1666,23 @@ void KPoGreController::slotSelectionChanged( const KPGTreeItem::eNodeType nodeTy
 		case KPGTreeItem::nodeFunction:
       	{
         	KPGFunction *pFunction = static_cast <KPGFunction *> (pItem);            
-        
+			KPGServer *pServer = static_cast <KPGServer *> (pFunction->getParentByType(KPGTreeItem::nodeServer));
+			
+			bool bVersion8_3 = false;
+			if(pServer) bVersion8_3 = (((pServer->versionMajor() == 8) && (pServer->versionMiddle() >= 3))
+						|| (pServer->versionMajor() > 8));
+			
 			KAction *pAct = pActionCollection->action("modify_function");
 			if(pAct)
 			{
 				pAct->setEnabled(pFunction->langName() != "c"); // Don't allow modify C function
 			}
+			
+			pAct = pActionCollection->action("debug_function");
+			if(pAct)
+			{
+				pAct->setEnabled(bVersion8_3 && (pFunction->langName() == "plpgsql")); // Allow debug only plpgsql function
+			}
       	}
       	break;
       
@@ -1734,7 +1745,7 @@ void KPoGreController::slotSelectionChanged( const KPGTreeItem::eNodeType nodeTy
 			KAction *pActSetOwner = pActionCollection->action("set_owner_schema");
 			if(pActSetOwner)
 			{
-			pActSetOwner->setEnabled(!pSchema->isSystemObject()); // Don't allow reowner system schema
+				pActSetOwner->setEnabled(!pSchema->isSystemObject()); // Don't allow reowner system schema
 			}
       	}
         break;
