@@ -27,6 +27,7 @@
 
 #include <qvaluelist.h>
 #include <qvaluestack.h>
+#include <qtoolbox.h>
 
 //includes files for KDE
 #include <kmdimainfrm.h>
@@ -61,6 +62,8 @@ class KPGFunction;
 class KPGConnection;
 class KPGKateXmlEditorDialog;
 
+class QListBoxItem;
+
 #define ID_STATUS_MSG 1
 
 /**
@@ -178,6 +181,9 @@ protected:
 	// Left tree view that displays DB objects tree	
 	QListView*  m_pViewTree;
 	
+	// Left toolbox with code snippets
+	QToolBox *m_pViewSnippets;
+	
 	// Dialog for editing XMLs in Kate editor
 	KPGKateXmlEditorDialog *m_pKateXmlEditorDialog;
 
@@ -195,7 +201,7 @@ protected:
     
 protected:  
    
-    // Sets up the statusbar for the main window by initialzing a status label.
+    // Sets up the statusbar for the main window by initializing a status label.
     void initStatusBar();
     
 	// Change cursor look
@@ -208,6 +214,9 @@ protected:
 	// Display properties of underlying database object
 	void displayProperties();
 	
+	// Initialize code snippets
+	void initializeSnippets();
+	
 /////////////////////////////////////////////////////////////////////
 //                     PUBLIC FUNCTIONS
 /////////////////////////////////////////////////////////////////////
@@ -497,13 +506,13 @@ protected slots:
 	void slotRequestListOfDatabaseObjectsForCodeCompletion(KPGQueryResultWindow *, const QString&);
 	
 	// Called, when is needed table columns list, for code completion 
-	void slotRequestTableColumnsListsForCodeCompletion(KPGQueryResultWindow *, pqxx::oid);
+	void slotRequestTableColumnsListsForCodeCompletion(KPGQueryResultWindow *, const KPGOidNameAliases *);
 	
 	// Called, when is needed schema childs list, for code completion 
 	void slotRequestSchemaChildsListsForCodeCompletion(KPGQueryResultWindow *, pqxx::oid);
 		
 	// Called, when is needed function return type attributes list, for code completion 
-	void slotRequestFunctionReturnTypeAttributesListsForCodeCompletion(KPGQueryResultWindow *, pqxx::oid);
+	void slotRequestFunctionReturnTypeAttributesListsForCodeCompletion(KPGQueryResultWindow *, const KPGOidNameAliases *);
 		
 	// Called from property pages when user double-clicks on KPGLinkLabel
 	void slotSearchObject(const pqxx::oid);
@@ -514,18 +523,9 @@ protected slots:
 	// Called when requested change terminal icon in this QTabWidget 
 	void slotSetTerminalIcon(KPGQueryResultWindow *, int);
 	
-	// Called when SQL query started or finished
-	//void slotQueryResultStateChanged(KPGQueryResultWindow *);
+	// Called when code snippet is choosed
+	void slotInsertSnippet(QListBoxItem *);
 	
-	// Called when SQL query started or finished, or actions need enable/desable
-	//void slotDataTableStateChanged(KPGDataTable* pDataTable);
-		
-	// Called when SQL query started or finished, or actions need enable/desable
-	//void slotExecutorStateChanged(KPGExecutor *);
-	
-	// Called when Debugger actions need enable/disable
-	//void slotDebuggerStateChanged(KPGDebugger *);
-		
 	//-------------------------------------------------------------------------
     //
     // Wizards functions
